------------------------------------------------------------------------
-- test5.vhd			Steven Sutankayo, Curtis Wickman
-- July 14, 1998
-- Test file for UA7k Project Board
-- 
-- Full board test --
-- Tests DIP Switches and pushbuttons, crystal oscillator,  
-- RC oscillator, all I/O pins for solder-bridges and stuck-at faults
------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;

entity test5 is
        port(
                pb1, pb2, gclk2, gclk1, input84 : in std_logic;       -- dedicated inputs

				iosig : inout std_logic_vector(1 to 45);
				
--				p28 : out std_logic;

				rc_in_p68  : in std_logic;
				rc_out_p69 : out std_logic;
				rc_neg_p73 : out std_logic; 
				rc_pos_p70 : out std_logic;
				
				led        : out std_logic_vector(1 to 2);
				dip : in std_logic_vector( 1 to 8 )
		            
        );
end;

architecture mixed of test5 is
	signal 	inputsig1, inputsig2,
			halved_crystal, combined_clock,
			slow_crystal,
			dip_on_1, dip_on_2, dip_on			: std_logic;
			
	signal 	clock_count	: std_logic_vector(23 downto 0);

begin

	---------------------------------------
	-- RC Oscillator logic
	rc_pos_p70 <= rc_in_p68;
	rc_neg_p73 <= not rc_in_p68;
	rc_out_p69 <= rc_in_p68;
	----------------------------------------

	---------------------------------------------
	-- clock divider process 
	-- halves the clock so that we don't run into
	-- timing problems with the clock counter
	---------------------------------------------
	clock_divider : process (gclk2) is
	begin
		if gclk2'event and gclk2 = '1' then
			if halved_crystal = '1' then
				halved_crystal <= '0';
			else
				halved_crystal <= '1';
			end if;
		end if;
	end process clock_divider;

	---------------------------------------------
	-- divides the halved clock by 4 million
	-- ( so 8 million in total )
	----------------------------------------------
	clock_counter : process (halved_crystal) is
	begin
		if halved_crystal'event and halved_crystal = '1' then

			-- check if we have counted to 2 million 1e8480
			if clock_count = x"1e8480" then
--													if clock_count = x"000080" then  -- (for simulation)
				clock_count <= x"000000";

				-- toggle the slow crystal	
				if slow_crystal = '1' then
					slow_crystal <= '0';
				else
					slow_crystal <= '1';
				end if;
			else 
			   clock_count <= clock_count + x"000001";
			end if;
			
		end if;	
	end process clock_counter;
			
	-------------------------------------------------------
	-- make_inputsignal 
	-- if any of the dip switches are closed, or any 
	-- pushbuttons are depressed, the input signal is set to 
	-- 0.  (this will turn on the LEDs)  Otherwise, the input 
	-- signal is the XOR of the Crystal and RC oscillators
	-------------------------------------------------------
	led(1) <= pb2 xor dip(5) xor dip(6) xor dip(7) xor dip(8);
	led(2) <= pb1 xor dip(1) xor dip(2) xor dip(3) xor dip(4) xor input84;

		
	combined_clock <= gclk1 xor slow_crystal;
	
	----------------------------------------------
	-- pin assignments
	-- the general purpose i/o pins are assigned 
	-- to each other sequentially so that faults 
	-- can be detected.
	----------------------------------------------
	iosig(1) <= combined_clock;
	iosig(2) <= not combined_clock;
	
	assign : for i in 1 to 21 generate -- (iosig'length-1)/2
	begin
		iosig(2*i+2) <= iosig(2*i);
		iosig(2*i+1) <= iosig(2*i-1);
	end generate;

	iosig(45) <= iosig(43);
	
end mixed;

