-- test5 (EPM7128SLC84-10)
--
-- Copyright (C) 1991-1997 Altera Corporation
-- Any megafunction design, and related net list (encrypted or decrypted),
-- support information, device programming or simulation file, and any other
-- associated documentation or information provided by Altera or a partner
-- under Altera's Megafunction Partnership Program may be used only to
-- program PLD devices (but not masked PLD devices) from Altera.  Any other
-- use of such megafunction design, net list, support information, device
-- programming or simulation file, or any other related documentation or
-- information is prohibited for any other purpose, including, but not
-- limited to modification, reverse engineering, de-compiling, or use with
-- any other silicon devices, unless such use is explicitly licensed under
-- a separate agreement with Altera or a megafunction partner.  Title to
-- the intellectual property, including patents, copyrights, trademarks,
-- trade secrets, or maskworks, embodied in any such megafunction design,
-- net list, support information, device programming or simulation file, or
-- any other related documentation or information provided by Altera or a
-- megafunction partner, remains with Altera, the megafunction partner, or
-- their respective licensors.  No other licenses, including any licenses
-- needed under any third party's intellectual property, are provided herein.
--
-- MAX+plus II Version 8.1 RC3 9/12/97
-- Wed Jul 22 15:13:17 1998

--

LIBRARY IEEE;
USE IEEE.std_logic_1164.all;

ENTITY TRIBUF_test5 IS
    GENERIC (
        ttri: TIME := 1 ns;
        ttxz: TIME := 1 ns;
        ttzx: TIME := 1 ns);
    PORT (
        in1 : IN std_logic;
        oe  : IN std_logic;
        y   : OUT std_logic);
END TRIBUF_test5;

ARCHITECTURE behavior OF TRIBUF_test5 IS
BEGIN
    PROCESS (in1, oe)
    BEGIN
        IF oe'EVENT THEN
            IF oe = '0' THEN
                y <= TRANSPORT 'Z' AFTER ttxz;
            ELSIF oe = '1' THEN
                y <= TRANSPORT in1 AFTER ttzx;
            END IF;
        ELSIF oe = '1' THEN
            y <= TRANSPORT in1 AFTER ttri;
        ELSIF oe = '0' THEN
            y <= TRANSPORT 'Z' AFTER ttxz;
        END IF;
    END PROCESS;
END behavior;

LIBRARY IEEE;
USE IEEE.std_logic_1164.all;

ENTITY DFF_test5 IS
    GENERIC (
	 data_pin : STRING;
      	 treg: TIME := 1 ns;
      	 trsu: TIME := 1 ns;
      	 trh : TIME := 1 ns;
      	 trpr: TIME := 1 ns;
      	 trcl: TIME := 1 ns);
    PORT (
      	 d   : IN std_logic;
      	 clk : IN std_logic;
      	 clrn: IN std_logic;
      	 prn : IN std_logic;
      	 q   : OUT std_logic := '0');
END DFF_test5;

ARCHITECTURE behavior OF DFF_test5 IS
BEGIN
    PROCESS (clk, d)
    BEGIN
        IF clk'EVENT AND clk = '1' THEN
            ASSERT d'STABLE (trsu)
                REPORT "DFF data pin " & data_pin & " : d changed within setup interval"
                SEVERITY Warning;
        END IF;
        IF d'EVENT AND clk = '1' THEN
            ASSERT clk'STABLE (trh)
                REPORT "DFF data pin " & data_pin & " : d changed within hold interval"
                SEVERITY Warning;
        END IF;
    END PROCESS;

    PROCESS (clk, clrn, prn)
        VARIABLE result : std_logic := '0';
        VARIABLE delay : TIME := 0 ns;
    BEGIN
        ASSERT NOT (prn = '0' AND clrn = '0')
            REPORT " prn and clrn both '0' on DFF"
            SEVERITY Warning;

        IF prn = '0' AND clrn = '1' THEN
            result := '1';
            delay := trpr;
        ELSIF prn = '1' AND clrn = '0' THEN
            result := '0';
            delay := trcl;
        ELSIF rising_edge(clk) THEN
            IF d = '1' OR d = '0' THEN
                result := d;
                delay := treg;
            END IF;
        END IF;

        IF result /= 'X' THEN
            q <= TRANSPORT result AFTER delay;
        END IF;

    END PROCESS;
END behavior;

LIBRARY IEEE;
USE IEEE.std_logic_1164.all;

ENTITY FILTER_test5 IS
    GENERIC (
        inst_name: STRING;
        tlow: TIME := 0 ns;
        thigh: TIME := 0 ns);
    PORT (
        in1 : IN std_logic;
        y: OUT std_logic);
END FILTER_test5;

ARCHITECTURE behavior OF FILTER_test5 IS
BEGIN
    PROCESS (in1)
        VARIABLE prev_event : TIME := 0 ns;
    BEGIN
        IF prev_event /= 0 ns THEN
            IF in1 = '1' THEN
                ASSERT Now - prev_event > tlow
                    REPORT "FILTER " & inst_name & " : Pulse width of '0' is less than tlow"
                    SEVERITY Warning;
            ELSIF in1 = '0' THEN
                ASSERT Now - prev_event > thigh
                    REPORT "FILTER " & inst_name & " : Pulse width of '1' is less than thigh"
                    SEVERITY Warning;
            END IF;
        END IF;

        prev_event := Now;
    END PROCESS;

    y <= in1;
END behavior;

LIBRARY IEEE;
USE IEEE.std_logic_1164.all;
USE work.tribuf_test5;
USE work.dff_test5;
USE work.filter_test5;

ENTITY test5 IS
    PORT (
      dip : IN std_logic_vector(1 to 8);
      led : OUT std_logic_vector(1 to 2);
      iosig : INOUT std_logic_vector(1 to 45);
      gclk1 : IN std_logic;
      gclk2 : IN std_logic;
      input84 : IN std_logic;
      pb1 : IN std_logic;
      pb2 : IN std_logic;
      rc_in_p68 : IN std_logic;
      rc_neg_p73 : OUT std_logic;
      rc_out_p69 : OUT std_logic;
      rc_pos_p70 : OUT std_logic);
END test5;

ARCHITECTURE \EPM7128SLC84-10\ OF test5 IS

SIGNAL gnd : std_logic := '0';
SIGNAL vcc : std_logic := '1';
SIGNAL
    n_253, \:8533\, n_255, n_256, n_257, n_259, n_260, slow_crystal_Q, n_262,
          \:8624\, n_264, n_265, n_266, n_267, n_268, n_269, n_270, n_271,
          n_272, n_273, n_274, n_275, n_276, n_277, n_278, n_279, n_280, n_281,
          n_282, n_283, n_284, n_285, n_286, n_287, n_288, n_289, n_290, n_291,
          n_292, n_293, n_294, n_295, n_296, n_297, n_298, n_299, n_300, n_301,
          n_302, n_303, n_304, n_305, n_306, n_307, n_308, n_309, n_310, n_311,
          n_312, n_313, n_314, n_315, n_316, n_317, n_318, n_319, n_320, n_321,
          n_322, n_323, n_324, n_325, n_326, n_327, n_328, n_329, n_330, n_331,
          n_332, n_333, n_334, n_335, n_336, n_337, n_338, n_339, n_340, n_341,
          n_342, n_343, n_344, n_345, n_346, n_347, n_348, n_349, n_350, n_351,
          n_352, n_353, n_354, n_355, n_356, n_357, n_358, n_359, n_360, n_361,
          n_362, n_363, n_364, n_365, n_366, n_367, n_368, n_369, n_370, n_371,
          n_372, n_373, n_374, n_375, n_376, n_377, n_378, n_379, n_380, n_381,
          n_382, n_383, n_384, n_385, n_386, n_387, n_388, n_389, n_390, n_391,
          n_392, n_393, n_394, n_395, n_396, n_397, n_398, n_399, n_400, n_401,
          n_402, n_403, n_404, n_405, n_406, n_407, n_408, n_409, n_410, n_411,
          n_412, n_413, n_414, n_415, n_416, n_417, n_418, n_419, n_420, n_421,
          n_422, n_423, n_424, n_425, n_426, n_427, n_428, n_429, n_430, n_431,
          n_432, n_433, n_434, n_435, n_436, n_437, n_438, n_439, n_440, n_441,
          n_442, n_443, n_444, n_445, n_446, n_447, n_448, n_449, n_450, n_451,
          n_452, n_453, n_454, n_455, n_456, n_457, n_458, n_459, n_460, n_461,
          n_462, n_463, n_464, n_465, n_466, n_467, n_468, n_469, n_470, n_471,
          n_472, n_473, n_474, n_475, n_476, n_477, n_478, n_479, n_480, n_481,
          n_482, n_483, n_484, n_485, n_486, n_487, n_488, n_489, n_490, n_491,
          n_492, n_493, n_494, n_495, n_496, n_498, n_499, \:8394\, n_501,
          n_502, n_503, n_504, n_505, n_506, n_507, n_508, n_509, \:8424\,
          n_511, n_512, n_513, n_514, n_515, n_517, n_519, n_521, n_523, n_524,
          n_525, n_526, n_527, n_528, n_529, n_530, n_531, n_532, n_533, n_534,
          n_535, n_536, n_537, n_538, n_539, n_540, n_541, n_542, n_543, n_544,
          n_545, n_546, n_547, n_548, n_549, n_550, n_551, n_552, n_553, n_554,
          n_555, n_556, n_557, n_558, n_559, n_560, n_561, n_562, n_563, n_564,
          n_565, n_566, n_568, n_569, n_570, n_571, n_572, \led2~fit~in1\,
          n_574, clock_count23_Q, \clock_count23.PRN\, \clock_count23.CLRN\,
          \clock_count23.D\, n_583, n_584, n_585, \|lpm_add_sub:2384|addcore:adder2|result_node7.OUT\,
          n_587, \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\,
          n_589, n_590, n_591, n_592, halved_crystal_Q, n_594, \clock_count23.CLK\,
          \|lpm_add_sub:2384|addcore:adder2|result_node7.IN\, n_597, n_598,
          n_599, n_600, n_601, clock_count22_Q, n_603, clock_count21_Q, n_605,
          clock_count20_Q, n_607, clock_count19_Q, n_609, clock_count18_Q,
          n_611, clock_count17_Q, n_613, clock_count16_Q, n_615, \|lpm_add_sub:2384|look_add:look_aheader|:42.OUT\,
          \clock_count22.PRN\, \clock_count22.CLRN\, \clock_count22.D\, n_624,
          n_625, n_626, \|lpm_add_sub:2384|addcore:adder2|result_node6.OUT\,
          n_628, n_629, \clock_count22.CLK\, \|lpm_add_sub:2384|addcore:adder2|result_node6.IN\,
          n_632, n_633, n_634, n_635, n_636, n_637, n_638, n_639, n_640, n_641,
          n_642, \clock_count21.PRN\, \clock_count21.CLRN\, \clock_count21.D\,
          n_650, n_651, n_652, \|lpm_add_sub:2384|addcore:adder2|result_node5.OUT\,
          n_654, n_655, n_656, n_657, n_658, n_659, \clock_count21.CLK\, \|lpm_add_sub:2384|addcore:adder2|result_node5.IN\,
          n_662, n_663, n_664, n_665, n_666, n_667, n_668, n_669, n_670, n_671,
          \clock_count20.PRN\, \clock_count20.CLRN\, \clock_count20.D\, n_679,
          n_680, n_681, n_682, \|lpm_add_sub:2384|addcore:adder2|result_node4.OUT\,
          n_684, n_685, n_686, n_687, n_688, \clock_count20.CLK\, \|lpm_add_sub:2384|addcore:adder2|result_node4.IN\,
          n_691, n_692, n_693, n_694, n_695, n_696, n_697, n_698, n_699, \clock_count19.PRN\,
          \clock_count19.CLRN\, \clock_count19.D\, n_707, n_708, n_709, n_710,
          \|lpm_add_sub:2384|addcore:adder2|result_node3.OUT\, n_712, n_713,
          n_714, \clock_count19.CLK\, \|lpm_add_sub:2384|addcore:adder2|result_node3.IN\,
          n_717, n_718, n_719, n_720, n_721, n_722, n_723, n_724, \clock_count18.PRN\,
          \clock_count18.CLRN\, \clock_count18.D\, n_732, n_733, n_734, n_735,
          \|lpm_add_sub:2384|addcore:adder2|result_node2.OUT\, n_737, n_738,
          n_739, \clock_count18.CLK\, \|lpm_add_sub:2384|addcore:adder2|result_node2.IN\,
          n_742, n_743, n_744, n_745, n_746, n_747, n_748, \clock_count17.PRN\,
          \clock_count17.CLRN\, \clock_count17.D\, n_756, n_757, n_758, n_759,
          \|lpm_add_sub:2384|addcore:adder2|result_node1.OUT\, n_761, n_762,
          n_763, n_764, n_765, \clock_count17.CLK\, \|lpm_add_sub:2384|addcore:adder2|result_node1.IN\,
          n_768, n_769, n_770, n_771, n_772, n_773, n_774, n_775, clock_count15_Q,
          n_777, clock_count14_Q, n_779, clock_count13_Q, n_781, clock_count12_Q,
          n_783, clock_count11_Q, n_785, clock_count10_Q, n_787, clock_count9_Q,
          n_789, clock_count8_Q, n_791, clock_count7_Q, n_793, clock_count6_Q,
          n_795, clock_count5_Q, n_797, clock_count4_Q, n_799, clock_count3_Q,
          n_801, clock_count2_Q, n_803, clock_count1_Q, n_805, clock_count0_Q,
          \clock_count16.PRN\, \clock_count16.CLRN\, \clock_count16.D\, n_814,
          n_815, n_816, n_817, \|lpm_add_sub:2384|addcore:adder2|result_node0.OUT\,
          n_819, n_820, n_821, \clock_count16.CLK\, \|lpm_add_sub:2384|addcore:adder2|result_node0.IN\,
          n_824, n_825, n_826, n_827, n_828, n_829, n_830, n_831, n_832, n_833,
          n_834, n_835, n_836, n_837, n_838, n_839, n_840, n_841, n_842, n_843,
          \clock_count15.PRN\, \clock_count15.CLRN\, \clock_count15.D\, n_851,
          n_852, n_853, \|lpm_add_sub:2384|addcore:adder1|result_node7.OUT\,
          n_855, n_856, n_857, n_858, \clock_count15.CLK\, \|lpm_add_sub:2384|addcore:adder1|result_node7.IN\,
          n_861, n_862, n_863, n_864, n_865, n_866, n_867, n_868, n_869, n_870,
          n_871, n_872, n_873, n_874, n_875, n_876, n_877, n_878, n_879, \clock_count14.PRN\,
          \clock_count14.CLRN\, \clock_count14.D\, n_887, n_888, n_889, \|lpm_add_sub:2384|addcore:adder1|result_node6.OUT\,
          n_891, n_892, \clock_count14.CLK\, \|lpm_add_sub:2384|addcore:adder1|result_node6.IN\,
          n_895, n_896, n_897, n_898, n_899, n_900, n_901, n_902, n_903, n_904,
          n_905, n_906, n_907, n_908, n_909, n_910, n_911, n_912, \clock_count13.PRN\,
          \clock_count13.CLRN\, \clock_count13.D\, n_920, n_921, n_922, \|lpm_add_sub:2384|addcore:adder1|result_node5.OUT\,
          n_924, n_925, \clock_count13.CLK\, \|lpm_add_sub:2384|addcore:adder1|result_node5.IN\,
          n_928, n_929, n_930, n_931, n_932, n_933, n_934, n_935, n_936, n_937,
          n_938, n_939, n_940, n_941, n_942, n_943, n_944, \clock_count12.PRN\,
          \clock_count12.CLRN\, \clock_count12.D\, n_952, n_953, n_954, n_955,
          \|lpm_add_sub:2384|addcore:adder1|result_node4.OUT\, n_957, n_958,
          n_959, \clock_count12.CLK\, \|lpm_add_sub:2384|addcore:adder1|result_node4.IN\,
          n_962, n_963, n_964, n_965, n_966, n_967, n_968, n_969, n_970, n_971,
          n_972, n_973, n_974, n_975, n_976, n_977, \clock_count11.PRN\, \clock_count11.CLRN\,
          \clock_count11.D\, n_985, n_986, n_987, n_988, \|lpm_add_sub:2384|addcore:adder1|result_node3.OUT\,
          n_990, n_991, n_992, \clock_count11.CLK\, \|lpm_add_sub:2384|addcore:adder1|result_node3.IN\,
          n_995, n_996, n_997, n_998, n_999, n_1000, n_1001, n_1002, n_1003,
          n_1004, n_1005, n_1006, n_1007, n_1008, n_1009, \clock_count10.PRN\,
          \clock_count10.CLRN\, \clock_count10.D\, n_1017, n_1018, n_1019,
          n_1020, \|lpm_add_sub:2384|addcore:adder1|result_node2.OUT\, n_1022,
          n_1023, n_1024, \clock_count10.CLK\, \|lpm_add_sub:2384|addcore:adder1|result_node2.IN\,
          n_1027, n_1028, n_1029, n_1030, n_1031, n_1032, n_1033, n_1034,
          n_1035, n_1036, n_1037, n_1038, n_1039, n_1040, \clock_count9.PRN\,
          \clock_count9.CLRN\, \clock_count9.D\, n_1048, n_1049, n_1050, n_1051,
          \|lpm_add_sub:2384|addcore:adder1|result_node1.OUT\, n_1053, n_1054,
          n_1055, \clock_count9.CLK\, \|lpm_add_sub:2384|addcore:adder1|result_node1.IN\,
          n_1058, n_1059, n_1060, n_1061, n_1062, n_1063, n_1064, n_1065,
          n_1066, n_1067, n_1068, n_1069, n_1070, \clock_count8.PRN\, \clock_count8.CLRN\,
          \clock_count8.D\, n_1078, n_1079, n_1080, n_1081, \|lpm_add_sub:2384|addcore:adder1|result_node0.OUT\,
          n_1083, n_1084, n_1085, n_1086, n_1087, \clock_count8.CLK\, \|lpm_add_sub:2384|addcore:adder1|result_node0.IN\,
          n_1090, n_1091, n_1092, n_1093, n_1094, n_1095, n_1096, n_1097,
          n_1098, n_1099, n_1100, n_1101, \clock_count7.PRN\, \clock_count7.CLRN\,
          \clock_count7.D\, n_1109, n_1110, n_1111, \|lpm_add_sub:2384|addcore:adder0|result_node7.OUT\,
          n_1113, n_1114, n_1115, n_1116, \clock_count7.CLK\, \|lpm_add_sub:2384|addcore:adder0|result_node7.IN\,
          n_1119, n_1120, n_1121, n_1122, n_1123, n_1124, n_1125, n_1126,
          n_1127, n_1128, n_1129, \clock_count6.PRN\, \clock_count6.CLRN\,
          \clock_count6.D\, n_1137, n_1138, n_1139, \|lpm_add_sub:2384|addcore:adder0|result_node6.OUT\,
          n_1141, n_1142, \clock_count6.CLK\, \|lpm_add_sub:2384|addcore:adder0|result_node6.IN\,
          n_1145, n_1146, n_1147, n_1148, n_1149, n_1150, n_1151, n_1152,
          n_1153, n_1154, \clock_count5.PRN\, \clock_count5.CLRN\, \clock_count5.D\,
          n_1162, n_1163, n_1164, \|lpm_add_sub:2384|addcore:adder0|result_node5.OUT\,
          n_1166, n_1167, \clock_count5.CLK\, \|lpm_add_sub:2384|addcore:adder0|result_node5.IN\,
          n_1170, n_1171, n_1172, n_1173, n_1174, n_1175, n_1176, n_1177,
          n_1178, \clock_count4.PRN\, \clock_count4.CLRN\, \clock_count4.D\,
          n_1186, n_1187, n_1188, n_1189, \|lpm_add_sub:2384|addcore:adder0|result_node4.OUT\,
          n_1191, n_1192, n_1193, \clock_count4.CLK\, \|lpm_add_sub:2384|addcore:adder0|result_node4.IN\,
          n_1196, n_1197, n_1198, n_1199, n_1200, n_1201, n_1202, n_1203,
          \clock_count3.PRN\, \clock_count3.CLRN\, \clock_count3.D\, n_1211,
          n_1212, n_1213, n_1214, \|lpm_add_sub:2384|addcore:adder0|result_node3.OUT\,
          n_1216, n_1217, n_1218, \clock_count3.CLK\, \|lpm_add_sub:2384|addcore:adder0|result_node3.IN\,
          n_1221, n_1222, n_1223, n_1224, n_1225, n_1226, n_1227, \clock_count2.PRN\,
          \clock_count2.CLRN\, \clock_count2.D\, n_1235, n_1236, n_1237, n_1238,
          \|lpm_add_sub:2384|addcore:adder0|result_node2.OUT\, n_1240, n_1241,
          n_1242, \clock_count2.CLK\, \|lpm_add_sub:2384|addcore:adder0|result_node2.IN\,
          n_1245, n_1246, n_1247, n_1248, n_1249, n_1250, \clock_count1.PRN\,
          \clock_count1.CLRN\, \clock_count1.D\, n_1258, n_1259, n_1260, n_1261,
          \|lpm_add_sub:2384|addcore:adder0|result_node1.OUT\, n_1263, n_1264,
          n_1265, \clock_count1.CLK\, \|lpm_add_sub:2384|addcore:adder0|result_node1.IN\,
          n_1268, n_1269, n_1270, n_1271, n_1272, \clock_count0.PRN\, \clock_count0.CLRN\,
          \clock_count0.D\, n_1280, n_1281, n_1282, n_1283, n_1284, n_1285,
          n_1286, n_1287, n_1288, \clock_count0.CLK\, \halved_crystal.PRN\,
          \halved_crystal.CLRN\, \halved_crystal.D\, \:2139\, n_1298, n_1299,
          \halved_crystal.CLK\, \|lpm_add_sub:2384|look_add:look_aheader|:42.IN\,
          n_1303, n_1304, \:8437\, n_1312, n_1313, n_1314, n_1315, n_1316,
          n_1317, n_1318, n_1319, n_1320, n_1321, n_1322, n_1323, n_1324,
          n_1325, n_1326, n_1327, n_1328, n_1329, n_1330, n_1331, n_1332,
          n_1333, n_1334, n_1335, n_1336, n_1337, n_1338, n_1339, n_1340,
          n_1341, n_1342, n_1343, n_1344, n_1345, n_1346, n_1347, n_1348,
          n_1349, n_1350, n_1351, n_1352, n_1353, n_1354, n_1355, n_1356,
          n_1357, n_1358, n_1359, n_1360, n_1361, n_1362, n_1363, n_1364,
          n_1365, n_1366, n_1367, n_1368, n_1369, n_1370, n_1371, n_1372,
          n_1373, n_1374, n_1375, n_1376, n_1377, n_1378, n_1379, n_1380,
          n_1381, n_1382, n_1383, n_1384, n_1385, n_1386, n_1387, n_1388,
          n_1389, n_1390, n_1391, n_1392, n_1393, n_1394, n_1395, n_1396,
          n_1397, n_1398, n_1399, n_1400, n_1401, n_1402, n_1403, n_1404,
          n_1405, n_1406, n_1407, n_1408, n_1409, n_1410, n_1411, n_1412,
          n_1413, n_1414, n_1415, n_1416, n_1417, n_1418, n_1419, n_1420,
          n_1421, n_1422, n_1423, n_1424, n_1425, n_1426, n_1427, \slow_crystal.PRN\,
          \slow_crystal.CLRN\, \slow_crystal.D\, \:2586\, n_1436, n_1437,
          n_1438, n_1439, n_1440, \slow_crystal.CLK\, \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.IN\,
          n_1443, n_1444, n_1445, n_1446, n_1447, n_1448, n_1449, n_1450,
          n_1451, n_1452, n_1453, n_1454, n_1455, n_1456, n_1457, n_1458,
          n_1459, n_1460, n_1461, n_1462, n_1463, n_1464, n_1465, n_1466,
          n_1467, n_1468, n_1469, n_1470 : std_logic;

COMPONENT TRIBUF_test5
    GENERIC (ttri, ttxz, ttzx: TIME);
    PORT (in1, oe  : IN std_logic; y : OUT std_logic);
END COMPONENT;

COMPONENT DFF_test5
    GENERIC (data_pin : STRING; treg, trsu, trh, trpr, trcl : TIME);
    PORT (d, clk, clrn, prn : IN std_logic; q : OUT std_logic);
END COMPONENT;

COMPONENT FILTER_test5
    GENERIC (inst_name: STRING; tlow, thigh: TIME);
    PORT (in1 : IN std_logic; y : OUT std_logic);
END COMPONENT;

BEGIN

PROCESS(dip(1), dip(2), dip(3), dip(4), dip(5), dip(6), dip(7), dip(8), gclk1, gclk2,
          input84, pb1, pb2, rc_in_p68)
BEGIN
    ASSERT dip(1) /= 'X' OR Now = 0 ns
        REPORT "Unknown value on dip(1)"
        SEVERITY Warning;
    ASSERT dip(2) /= 'X' OR Now = 0 ns
        REPORT "Unknown value on dip(2)"
        SEVERITY Warning;
    ASSERT dip(3) /= 'X' OR Now = 0 ns
        REPORT "Unknown value on dip(3)"
        SEVERITY Warning;
    ASSERT dip(4) /= 'X' OR Now = 0 ns
        REPORT "Unknown value on dip(4)"
        SEVERITY Warning;
    ASSERT dip(5) /= 'X' OR Now = 0 ns
        REPORT "Unknown value on dip(5)"
        SEVERITY Warning;
    ASSERT dip(6) /= 'X' OR Now = 0 ns
        REPORT "Unknown value on dip(6)"
        SEVERITY Warning;
    ASSERT dip(7) /= 'X' OR Now = 0 ns
        REPORT "Unknown value on dip(7)"
        SEVERITY Warning;
    ASSERT dip(8) /= 'X' OR Now = 0 ns
        REPORT "Unknown value on dip(8)"
        SEVERITY Warning;
    ASSERT gclk1 /= 'X' OR Now = 0 ns
        REPORT "Unknown value on gclk1"
        SEVERITY Warning;
    ASSERT gclk2 /= 'X' OR Now = 0 ns
        REPORT "Unknown value on gclk2"
        SEVERITY Warning;
    ASSERT input84 /= 'X' OR Now = 0 ns
        REPORT "Unknown value on input84"
        SEVERITY Warning;
    ASSERT pb1 /= 'X' OR Now = 0 ns
        REPORT "Unknown value on pb1"
        SEVERITY Warning;
    ASSERT pb2 /= 'X' OR Now = 0 ns
        REPORT "Unknown value on pb2"
        SEVERITY Warning;
    ASSERT rc_in_p68 /= 'X' OR Now = 0 ns
        REPORT "Unknown value on rc_in_p68"
        SEVERITY Warning;
END PROCESS;

tribuf_2: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_253, OE => vcc, Y => iosig(1));
tribuf_4: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_262, OE => vcc, Y => iosig(2));
tribuf_6: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_267, OE => vcc, Y => iosig(3));
tribuf_8: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_273, OE => vcc, Y => iosig(4));
tribuf_10: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_278, OE => vcc, Y => iosig(5));
tribuf_12: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_283, OE => vcc, Y => iosig(6));
tribuf_14: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_288, OE => vcc, Y => iosig(7));
tribuf_16: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_293, OE => vcc, Y => iosig(8));
tribuf_18: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_298, OE => vcc, Y => iosig(9));
tribuf_20: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_304, OE => vcc, Y => iosig(10));
tribuf_22: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_309, OE => vcc, Y => iosig(11));
tribuf_24: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_314, OE => vcc, Y => iosig(12));
tribuf_26: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_319, OE => vcc, Y => iosig(13));
tribuf_28: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_324, OE => vcc, Y => iosig(14));
tribuf_30: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_329, OE => vcc, Y => iosig(15));
tribuf_32: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_334, OE => vcc, Y => iosig(16));
tribuf_34: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_340, OE => vcc, Y => iosig(17));
tribuf_36: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_345, OE => vcc, Y => iosig(18));
tribuf_38: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_351, OE => vcc, Y => iosig(19));
tribuf_40: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_357, OE => vcc, Y => iosig(20));
tribuf_42: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_362, OE => vcc, Y => iosig(21));
tribuf_44: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_367, OE => vcc, Y => iosig(22));
tribuf_46: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_372, OE => vcc, Y => iosig(23));
tribuf_48: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_377, OE => vcc, Y => iosig(24));
tribuf_50: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_383, OE => vcc, Y => iosig(25));
tribuf_52: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_388, OE => vcc, Y => iosig(26));
tribuf_54: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_393, OE => vcc, Y => iosig(27));
tribuf_56: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_398, OE => vcc, Y => iosig(28));
tribuf_58: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_403, OE => vcc, Y => iosig(29));
tribuf_60: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_408, OE => vcc, Y => iosig(30));
tribuf_62: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_413, OE => vcc, Y => iosig(31));
tribuf_64: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_419, OE => vcc, Y => iosig(32));
tribuf_66: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_424, OE => vcc, Y => iosig(33));
tribuf_68: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_430, OE => vcc, Y => iosig(34));
tribuf_70: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_435, OE => vcc, Y => iosig(35));
tribuf_72: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_440, OE => vcc, Y => iosig(36));
tribuf_74: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_445, OE => vcc, Y => iosig(37));
tribuf_76: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_451, OE => vcc, Y => iosig(38));
tribuf_78: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_456, OE => vcc, Y => iosig(39));
tribuf_80: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_461, OE => vcc, Y => iosig(40));
tribuf_82: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_466, OE => vcc, Y => iosig(41));
tribuf_84: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_471, OE => vcc, Y => iosig(42));
tribuf_86: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_476, OE => vcc, Y => iosig(43));
tribuf_88: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_481, OE => vcc, Y => iosig(44));
tribuf_90: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_487, OE => vcc, Y => iosig(45));
tribuf_92: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_492, OE => vcc, Y => rc_out_p69);
tribuf_94: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_499, OE => vcc, Y => rc_neg_p73);
tribuf_96: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_505, OE => vcc, Y => rc_pos_p70);
tribuf_98: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_509, OE => vcc, Y => led(1));
tribuf_100: TRIBUF_test5
    GENERIC MAP (ttri => 1500 ps, ttxz => 5 ns, ttzx => 5 ns)
    PORT MAP (IN1 => n_568, OE => vcc, Y => led(2));
delay_101: n_253  <= TRANSPORT \:8533\ AFTER 2 ns;
xor2_102: \:8533\ <=  n_255  XOR n_259;
or1_103: n_255 <=  n_256;
and1_104: n_256 <= TRANSPORT  n_257 AFTER 5 ns;
delay_105: n_257  <= TRANSPORT gclk1 AFTER 1500 ps;
and1_106: n_259 <= TRANSPORT  n_260 AFTER 5 ns;
delay_107: n_260  <= TRANSPORT slow_crystal_Q AFTER 1 ns;
delay_108: n_262  <= TRANSPORT \:8624\ AFTER 2 ns;
xor2_109: \:8624\ <=  n_264  XOR n_259;
or1_110: n_264 <=  n_265;
and1_111: n_265 <= TRANSPORT  n_266 AFTER 5 ns;
inv_112: n_266  <= TRANSPORT NOT gclk1 AFTER 1500 ps;
delay_113: n_267  <= TRANSPORT n_268 AFTER 2 ns;
xor2_114: n_268 <=  n_269  XOR n_272;
or1_115: n_269 <=  n_270;
and1_116: n_270 <= TRANSPORT  n_271 AFTER 5 ns;
delay_117: n_271  <= TRANSPORT iosig(1) AFTER 1500 ps;
and1_118: n_272 <= TRANSPORT  gnd AFTER 5 ns;
delay_119: n_273  <= TRANSPORT n_274 AFTER 2 ns;
xor2_120: n_274 <=  n_275  XOR n_272;
or1_121: n_275 <=  n_276;
and1_122: n_276 <= TRANSPORT  n_277 AFTER 5 ns;
delay_123: n_277  <= TRANSPORT iosig(2) AFTER 1500 ps;
delay_124: n_278  <= TRANSPORT n_279 AFTER 2 ns;
xor2_125: n_279 <=  n_280  XOR n_272;
or1_126: n_280 <=  n_281;
and1_127: n_281 <= TRANSPORT  n_282 AFTER 5 ns;
delay_128: n_282  <= TRANSPORT iosig(3) AFTER 1500 ps;
delay_129: n_283  <= TRANSPORT n_284 AFTER 2 ns;
xor2_130: n_284 <=  n_285  XOR n_272;
or1_131: n_285 <=  n_286;
and1_132: n_286 <= TRANSPORT  n_287 AFTER 5 ns;
delay_133: n_287  <= TRANSPORT iosig(4) AFTER 1500 ps;
delay_134: n_288  <= TRANSPORT n_289 AFTER 2 ns;
xor2_135: n_289 <=  n_290  XOR n_272;
or1_136: n_290 <=  n_291;
and1_137: n_291 <= TRANSPORT  n_292 AFTER 5 ns;
delay_138: n_292  <= TRANSPORT iosig(5) AFTER 1500 ps;
delay_139: n_293  <= TRANSPORT n_294 AFTER 2 ns;
xor2_140: n_294 <=  n_295  XOR n_272;
or1_141: n_295 <=  n_296;
and1_142: n_296 <= TRANSPORT  n_297 AFTER 5 ns;
delay_143: n_297  <= TRANSPORT iosig(6) AFTER 1500 ps;
delay_144: n_298  <= TRANSPORT n_299 AFTER 2 ns;
xor2_145: n_299 <=  n_300  XOR n_303;
or1_146: n_300 <=  n_301;
and1_147: n_301 <= TRANSPORT  n_302 AFTER 5 ns;
delay_148: n_302  <= TRANSPORT iosig(7) AFTER 1500 ps;
and1_149: n_303 <= TRANSPORT  gnd AFTER 5 ns;
delay_150: n_304  <= TRANSPORT n_305 AFTER 2 ns;
xor2_151: n_305 <=  n_306  XOR n_303;
or1_152: n_306 <=  n_307;
and1_153: n_307 <= TRANSPORT  n_308 AFTER 5 ns;
delay_154: n_308  <= TRANSPORT iosig(8) AFTER 1500 ps;
delay_155: n_309  <= TRANSPORT n_310 AFTER 2 ns;
xor2_156: n_310 <=  n_311  XOR n_303;
or1_157: n_311 <=  n_312;
and1_158: n_312 <= TRANSPORT  n_313 AFTER 5 ns;
delay_159: n_313  <= TRANSPORT iosig(9) AFTER 1500 ps;
delay_160: n_314  <= TRANSPORT n_315 AFTER 2 ns;
xor2_161: n_315 <=  n_316  XOR n_303;
or1_162: n_316 <=  n_317;
and1_163: n_317 <= TRANSPORT  n_318 AFTER 5 ns;
delay_164: n_318  <= TRANSPORT iosig(10) AFTER 1500 ps;
delay_165: n_319  <= TRANSPORT n_320 AFTER 2 ns;
xor2_166: n_320 <=  n_321  XOR n_303;
or1_167: n_321 <=  n_322;
and1_168: n_322 <= TRANSPORT  n_323 AFTER 5 ns;
delay_169: n_323  <= TRANSPORT iosig(11) AFTER 1500 ps;
delay_170: n_324  <= TRANSPORT n_325 AFTER 2 ns;
xor2_171: n_325 <=  n_326  XOR n_303;
or1_172: n_326 <=  n_327;
and1_173: n_327 <= TRANSPORT  n_328 AFTER 5 ns;
delay_174: n_328  <= TRANSPORT iosig(12) AFTER 1500 ps;
delay_175: n_329  <= TRANSPORT n_330 AFTER 2 ns;
xor2_176: n_330 <=  n_331  XOR n_303;
or1_177: n_331 <=  n_332;
and1_178: n_332 <= TRANSPORT  n_333 AFTER 5 ns;
delay_179: n_333  <= TRANSPORT iosig(13) AFTER 1500 ps;
delay_180: n_334  <= TRANSPORT n_335 AFTER 2 ns;
xor2_181: n_335 <=  n_336  XOR n_339;
or1_182: n_336 <=  n_337;
and1_183: n_337 <= TRANSPORT  n_338 AFTER 5 ns;
delay_184: n_338  <= TRANSPORT iosig(14) AFTER 1500 ps;
and1_185: n_339 <= TRANSPORT  gnd AFTER 5 ns;
delay_186: n_340  <= TRANSPORT n_341 AFTER 2 ns;
xor2_187: n_341 <=  n_342  XOR n_339;
or1_188: n_342 <=  n_343;
and1_189: n_343 <= TRANSPORT  n_344 AFTER 5 ns;
delay_190: n_344  <= TRANSPORT iosig(15) AFTER 1500 ps;
delay_191: n_345  <= TRANSPORT n_346 AFTER 2 ns;
xor2_192: n_346 <=  n_347  XOR n_350;
or1_193: n_347 <=  n_348;
and1_194: n_348 <= TRANSPORT  n_349 AFTER 5 ns;
delay_195: n_349  <= TRANSPORT iosig(16) AFTER 1500 ps;
and1_196: n_350 <= TRANSPORT  gnd AFTER 5 ns;
delay_197: n_351  <= TRANSPORT n_352 AFTER 2 ns;
xor2_198: n_352 <=  n_353  XOR n_356;
or1_199: n_353 <=  n_354;
and1_200: n_354 <= TRANSPORT  n_355 AFTER 5 ns;
delay_201: n_355  <= TRANSPORT iosig(17) AFTER 1500 ps;
and1_202: n_356 <= TRANSPORT  gnd AFTER 5 ns;
delay_203: n_357  <= TRANSPORT n_358 AFTER 2 ns;
xor2_204: n_358 <=  n_359  XOR n_356;
or1_205: n_359 <=  n_360;
and1_206: n_360 <= TRANSPORT  n_361 AFTER 5 ns;
delay_207: n_361  <= TRANSPORT iosig(18) AFTER 1500 ps;
delay_208: n_362  <= TRANSPORT n_363 AFTER 2 ns;
xor2_209: n_363 <=  n_364  XOR n_356;
or1_210: n_364 <=  n_365;
and1_211: n_365 <= TRANSPORT  n_366 AFTER 5 ns;
delay_212: n_366  <= TRANSPORT iosig(19) AFTER 1500 ps;
delay_213: n_367  <= TRANSPORT n_368 AFTER 2 ns;
xor2_214: n_368 <=  n_369  XOR n_356;
or1_215: n_369 <=  n_370;
and1_216: n_370 <= TRANSPORT  n_371 AFTER 5 ns;
delay_217: n_371  <= TRANSPORT iosig(20) AFTER 1500 ps;
delay_218: n_372  <= TRANSPORT n_373 AFTER 2 ns;
xor2_219: n_373 <=  n_374  XOR n_356;
or1_220: n_374 <=  n_375;
and1_221: n_375 <= TRANSPORT  n_376 AFTER 5 ns;
delay_222: n_376  <= TRANSPORT iosig(21) AFTER 1500 ps;
delay_223: n_377  <= TRANSPORT n_378 AFTER 2 ns;
xor2_224: n_378 <=  n_379  XOR n_382;
or1_225: n_379 <=  n_380;
and1_226: n_380 <= TRANSPORT  n_381 AFTER 5 ns;
delay_227: n_381  <= TRANSPORT iosig(22) AFTER 1500 ps;
and1_228: n_382 <= TRANSPORT  gnd AFTER 5 ns;
delay_229: n_383  <= TRANSPORT n_384 AFTER 2 ns;
xor2_230: n_384 <=  n_385  XOR n_382;
or1_231: n_385 <=  n_386;
and1_232: n_386 <= TRANSPORT  n_387 AFTER 5 ns;
delay_233: n_387  <= TRANSPORT iosig(23) AFTER 1500 ps;
delay_234: n_388  <= TRANSPORT n_389 AFTER 2 ns;
xor2_235: n_389 <=  n_390  XOR n_382;
or1_236: n_390 <=  n_391;
and1_237: n_391 <= TRANSPORT  n_392 AFTER 5 ns;
delay_238: n_392  <= TRANSPORT iosig(24) AFTER 1500 ps;
delay_239: n_393  <= TRANSPORT n_394 AFTER 2 ns;
xor2_240: n_394 <=  n_395  XOR n_382;
or1_241: n_395 <=  n_396;
and1_242: n_396 <= TRANSPORT  n_397 AFTER 5 ns;
delay_243: n_397  <= TRANSPORT iosig(25) AFTER 1500 ps;
delay_244: n_398  <= TRANSPORT n_399 AFTER 2 ns;
xor2_245: n_399 <=  n_400  XOR n_382;
or1_246: n_400 <=  n_401;
and1_247: n_401 <= TRANSPORT  n_402 AFTER 5 ns;
delay_248: n_402  <= TRANSPORT iosig(26) AFTER 1500 ps;
delay_249: n_403  <= TRANSPORT n_404 AFTER 2 ns;
xor2_250: n_404 <=  n_405  XOR n_382;
or1_251: n_405 <=  n_406;
and1_252: n_406 <= TRANSPORT  n_407 AFTER 5 ns;
delay_253: n_407  <= TRANSPORT iosig(27) AFTER 1500 ps;
delay_254: n_408  <= TRANSPORT n_409 AFTER 2 ns;
xor2_255: n_409 <=  n_410  XOR n_382;
or1_256: n_410 <=  n_411;
and1_257: n_411 <= TRANSPORT  n_412 AFTER 5 ns;
delay_258: n_412  <= TRANSPORT iosig(28) AFTER 1500 ps;
delay_259: n_413  <= TRANSPORT n_414 AFTER 2 ns;
xor2_260: n_414 <=  n_415  XOR n_418;
or1_261: n_415 <=  n_416;
and1_262: n_416 <= TRANSPORT  n_417 AFTER 5 ns;
delay_263: n_417  <= TRANSPORT iosig(29) AFTER 1500 ps;
and1_264: n_418 <= TRANSPORT  gnd AFTER 5 ns;
delay_265: n_419  <= TRANSPORT n_420 AFTER 2 ns;
xor2_266: n_420 <=  n_421  XOR n_418;
or1_267: n_421 <=  n_422;
and1_268: n_422 <= TRANSPORT  n_423 AFTER 5 ns;
delay_269: n_423  <= TRANSPORT iosig(30) AFTER 1500 ps;
delay_270: n_424  <= TRANSPORT n_425 AFTER 2 ns;
xor2_271: n_425 <=  n_426  XOR n_429;
or1_272: n_426 <=  n_427;
and1_273: n_427 <= TRANSPORT  n_428 AFTER 5 ns;
delay_274: n_428  <= TRANSPORT iosig(31) AFTER 1500 ps;
and1_275: n_429 <= TRANSPORT  gnd AFTER 5 ns;
delay_276: n_430  <= TRANSPORT n_431 AFTER 2 ns;
xor2_277: n_431 <=  n_432  XOR n_429;
or1_278: n_432 <=  n_433;
and1_279: n_433 <= TRANSPORT  n_434 AFTER 5 ns;
delay_280: n_434  <= TRANSPORT iosig(32) AFTER 1500 ps;
delay_281: n_435  <= TRANSPORT n_436 AFTER 2 ns;
xor2_282: n_436 <=  n_437  XOR n_429;
or1_283: n_437 <=  n_438;
and1_284: n_438 <= TRANSPORT  n_439 AFTER 5 ns;
delay_285: n_439  <= TRANSPORT iosig(33) AFTER 1500 ps;
delay_286: n_440  <= TRANSPORT n_441 AFTER 2 ns;
xor2_287: n_441 <=  n_442  XOR n_429;
or1_288: n_442 <=  n_443;
and1_289: n_443 <= TRANSPORT  n_444 AFTER 5 ns;
delay_290: n_444  <= TRANSPORT iosig(34) AFTER 1500 ps;
delay_291: n_445  <= TRANSPORT n_446 AFTER 2 ns;
xor2_292: n_446 <=  n_447  XOR n_450;
or1_293: n_447 <=  n_448;
and1_294: n_448 <= TRANSPORT  n_449 AFTER 5 ns;
delay_295: n_449  <= TRANSPORT iosig(35) AFTER 1500 ps;
and1_296: n_450 <= TRANSPORT  gnd AFTER 5 ns;
delay_297: n_451  <= TRANSPORT n_452 AFTER 2 ns;
xor2_298: n_452 <=  n_453  XOR n_450;
or1_299: n_453 <=  n_454;
and1_300: n_454 <= TRANSPORT  n_455 AFTER 5 ns;
delay_301: n_455  <= TRANSPORT iosig(36) AFTER 1500 ps;
delay_302: n_456  <= TRANSPORT n_457 AFTER 2 ns;
xor2_303: n_457 <=  n_458  XOR n_450;
or1_304: n_458 <=  n_459;
and1_305: n_459 <= TRANSPORT  n_460 AFTER 5 ns;
delay_306: n_460  <= TRANSPORT iosig(37) AFTER 1500 ps;
delay_307: n_461  <= TRANSPORT n_462 AFTER 2 ns;
xor2_308: n_462 <=  n_463  XOR n_450;
or1_309: n_463 <=  n_464;
and1_310: n_464 <= TRANSPORT  n_465 AFTER 5 ns;
delay_311: n_465  <= TRANSPORT iosig(38) AFTER 1500 ps;
delay_312: n_466  <= TRANSPORT n_467 AFTER 2 ns;
xor2_313: n_467 <=  n_468  XOR n_450;
or1_314: n_468 <=  n_469;
and1_315: n_469 <= TRANSPORT  n_470 AFTER 5 ns;
delay_316: n_470  <= TRANSPORT iosig(39) AFTER 1500 ps;
delay_317: n_471  <= TRANSPORT n_472 AFTER 2 ns;
xor2_318: n_472 <=  n_473  XOR n_450;
or1_319: n_473 <=  n_474;
and1_320: n_474 <= TRANSPORT  n_475 AFTER 5 ns;
delay_321: n_475  <= TRANSPORT iosig(40) AFTER 1500 ps;
delay_322: n_476  <= TRANSPORT n_477 AFTER 2 ns;
xor2_323: n_477 <=  n_478  XOR n_450;
or1_324: n_478 <=  n_479;
and1_325: n_479 <= TRANSPORT  n_480 AFTER 5 ns;
delay_326: n_480  <= TRANSPORT iosig(41) AFTER 1500 ps;
delay_327: n_481  <= TRANSPORT n_482 AFTER 2 ns;
xor2_328: n_482 <=  n_483  XOR n_486;
or1_329: n_483 <=  n_484;
and1_330: n_484 <= TRANSPORT  n_485 AFTER 5 ns;
delay_331: n_485  <= TRANSPORT iosig(42) AFTER 1500 ps;
and1_332: n_486 <= TRANSPORT  gnd AFTER 5 ns;
delay_333: n_487  <= TRANSPORT n_488 AFTER 2 ns;
xor2_334: n_488 <=  n_489  XOR n_486;
or1_335: n_489 <=  n_490;
and1_336: n_490 <= TRANSPORT  n_491 AFTER 5 ns;
delay_337: n_491  <= TRANSPORT iosig(43) AFTER 1500 ps;
delay_338: n_492  <= TRANSPORT n_493 AFTER 2 ns;
xor2_339: n_493 <=  n_494  XOR n_498;
or1_340: n_494 <=  n_495;
and1_341: n_495 <= TRANSPORT  n_496 AFTER 5 ns;
delay_342: n_496  <= TRANSPORT rc_in_p68 AFTER 1500 ps;
and1_343: n_498 <= TRANSPORT  gnd AFTER 5 ns;
delay_344: n_499  <= TRANSPORT \:8394\ AFTER 2 ns;
xor2_345: \:8394\ <=  n_501  XOR n_504;
or1_346: n_501 <=  n_502;
and1_347: n_502 <= TRANSPORT  n_503 AFTER 5 ns;
inv_348: n_503  <= TRANSPORT NOT rc_in_p68 AFTER 1500 ps;
and1_349: n_504 <= TRANSPORT  gnd AFTER 5 ns;
delay_350: n_505  <= TRANSPORT n_506 AFTER 2 ns;
xor2_351: n_506 <=  n_507  XOR n_508;
or1_352: n_507 <=  n_495;
and1_353: n_508 <= TRANSPORT  gnd AFTER 5 ns;
delay_354: n_509  <= TRANSPORT \:8424\ AFTER 2 ns;
xor2_355: \:8424\ <=  n_511  XOR n_565;
or1_356: n_511 <=  n_512;
and8_357: n_512 <= TRANSPORT  n_513  AND n_523  AND n_529  AND n_535  AND n_541
           AND n_547  AND n_553  AND n_559 AFTER 5 ns;
inv_358: n_513  <= TRANSPORT NOT n_514;
and4_359: n_514 <= TRANSPORT  n_515  AND n_517  AND n_519  AND n_521 AFTER 5 ns;
inv_360: n_515  <= TRANSPORT NOT dip(6) AFTER 1500 ps;
inv_361: n_517  <= TRANSPORT NOT dip(5) AFTER 1500 ps;
inv_362: n_519  <= TRANSPORT NOT pb2 AFTER 1500 ps;
delay_363: n_521  <= TRANSPORT dip(7) AFTER 1500 ps;
inv_364: n_523  <= TRANSPORT NOT n_524;
and4_365: n_524 <= TRANSPORT  n_525  AND n_526  AND n_527  AND n_528 AFTER 5 ns;
inv_366: n_525  <= TRANSPORT NOT dip(7) AFTER 1500 ps;
inv_367: n_526  <= TRANSPORT NOT dip(5) AFTER 1500 ps;
inv_368: n_527  <= TRANSPORT NOT pb2 AFTER 1500 ps;
delay_369: n_528  <= TRANSPORT dip(6) AFTER 1500 ps;
inv_370: n_529  <= TRANSPORT NOT n_530;
and4_371: n_530 <= TRANSPORT  n_531  AND n_532  AND n_533  AND n_534 AFTER 5 ns;
inv_372: n_531  <= TRANSPORT NOT dip(7) AFTER 1500 ps;
inv_373: n_532  <= TRANSPORT NOT dip(6) AFTER 1500 ps;
inv_374: n_533  <= TRANSPORT NOT pb2 AFTER 1500 ps;
delay_375: n_534  <= TRANSPORT dip(5) AFTER 1500 ps;
inv_376: n_535  <= TRANSPORT NOT n_536;
and4_377: n_536 <= TRANSPORT  n_537  AND n_538  AND n_539  AND n_540 AFTER 5 ns;
inv_378: n_537  <= TRANSPORT NOT dip(7) AFTER 1500 ps;
inv_379: n_538  <= TRANSPORT NOT dip(6) AFTER 1500 ps;
inv_380: n_539  <= TRANSPORT NOT dip(5) AFTER 1500 ps;
delay_381: n_540  <= TRANSPORT pb2 AFTER 1500 ps;
inv_382: n_541  <= TRANSPORT NOT n_542;
and4_383: n_542 <= TRANSPORT  n_543  AND n_544  AND n_545  AND n_546 AFTER 5 ns;
inv_384: n_543  <= TRANSPORT NOT pb2 AFTER 1500 ps;
delay_385: n_544  <= TRANSPORT dip(5) AFTER 1500 ps;
delay_386: n_545  <= TRANSPORT dip(6) AFTER 1500 ps;
delay_387: n_546  <= TRANSPORT dip(7) AFTER 1500 ps;
inv_388: n_547  <= TRANSPORT NOT n_548;
and4_389: n_548 <= TRANSPORT  n_549  AND n_550  AND n_551  AND n_552 AFTER 5 ns;
inv_390: n_549  <= TRANSPORT NOT dip(5) AFTER 1500 ps;
delay_391: n_550  <= TRANSPORT pb2 AFTER 1500 ps;
delay_392: n_551  <= TRANSPORT dip(6) AFTER 1500 ps;
delay_393: n_552  <= TRANSPORT dip(7) AFTER 1500 ps;
inv_394: n_553  <= TRANSPORT NOT n_554;
and4_395: n_554 <= TRANSPORT  n_555  AND n_556  AND n_557  AND n_558 AFTER 5 ns;
inv_396: n_555  <= TRANSPORT NOT dip(6) AFTER 1500 ps;
delay_397: n_556  <= TRANSPORT pb2 AFTER 1500 ps;
delay_398: n_557  <= TRANSPORT dip(5) AFTER 1500 ps;
delay_399: n_558  <= TRANSPORT dip(7) AFTER 1500 ps;
inv_400: n_559  <= TRANSPORT NOT n_560;
and4_401: n_560 <= TRANSPORT  n_561  AND n_562  AND n_563  AND n_564 AFTER 5 ns;
inv_402: n_561  <= TRANSPORT NOT dip(7) AFTER 1500 ps;
delay_403: n_562  <= TRANSPORT pb2 AFTER 1500 ps;
delay_404: n_563  <= TRANSPORT dip(5) AFTER 1500 ps;
delay_405: n_564  <= TRANSPORT dip(6) AFTER 1500 ps;
and1_406: n_565 <= TRANSPORT  n_566 AFTER 5 ns;
inv_407: n_566  <= TRANSPORT NOT dip(8) AFTER 1500 ps;
delay_408: n_568  <= TRANSPORT n_569 AFTER 2 ns;
xor2_409: n_569 <=  n_570  XOR n_574;
or1_410: n_570 <=  n_571;
and1_411: n_571 <= TRANSPORT  n_572 AFTER 5 ns;
delay_412: n_572  <= TRANSPORT \led2~fit~in1\ AFTER 1 ns;
and1_413: n_574 <= TRANSPORT  gnd AFTER 5 ns;
dff_414: DFF_test5
    GENERIC MAP (data_pin => " \clock_count23.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count23.D\, CLK => \clock_count23.CLK\, CLRN => \clock_count23.CLRN\,
          PRN => \clock_count23.PRN\, Q => clock_count23_Q);
inv_415: \clock_count23.PRN\  <= TRANSPORT NOT gnd;
inv_416: \clock_count23.CLRN\  <= TRANSPORT NOT gnd;
xor2_417: \clock_count23.D\ <=  n_583  XOR n_589;
or1_418: n_583 <=  n_584;
and2_419: n_584 <= TRANSPORT  n_585  AND n_587 AFTER 5 ns;
inv_420: n_585  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder2|result_node7.OUT\ AFTER 1 ns;
inv_421: n_587  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
and1_422: n_589 <= TRANSPORT  n_590 AFTER 5 ns;
inv_423: n_590  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
and1_424: n_591 <= TRANSPORT  n_592 AFTER 5 ns;
delay_425: n_592  <= TRANSPORT halved_crystal_Q AFTER 1 ns;
delay_426: n_594  <= TRANSPORT n_591;
filter_427: FILTER_test5
    GENERIC MAP (inst_name => "filter_427", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_594, Y => \clock_count23.CLK\);
delay_428: \|lpm_add_sub:2384|addcore:adder2|result_node7.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node7.IN\ AFTER 2 ns;
xor2_429: \|lpm_add_sub:2384|addcore:adder2|result_node7.IN\ <=  n_597  XOR n_600;
or1_430: n_597 <=  n_598;
and1_431: n_598 <= TRANSPORT  n_599 AFTER 5 ns;
delay_432: n_599  <= TRANSPORT clock_count23_Q AFTER 1 ns;
and8_433: n_600 <= TRANSPORT  n_601  AND n_603  AND n_605  AND n_607  AND n_609
           AND n_611  AND n_613  AND n_615 AFTER 5 ns;
delay_434: n_601  <= TRANSPORT clock_count22_Q AFTER 1 ns;
delay_435: n_603  <= TRANSPORT clock_count21_Q AFTER 1 ns;
delay_436: n_605  <= TRANSPORT clock_count20_Q AFTER 1 ns;
delay_437: n_607  <= TRANSPORT clock_count19_Q AFTER 1 ns;
delay_438: n_609  <= TRANSPORT clock_count18_Q AFTER 1 ns;
delay_439: n_611  <= TRANSPORT clock_count17_Q AFTER 1 ns;
delay_440: n_613  <= TRANSPORT clock_count16_Q AFTER 1 ns;
delay_441: n_615  <= TRANSPORT \|lpm_add_sub:2384|look_add:look_aheader|:42.OUT\ AFTER 1 ns;
dff_442: DFF_test5
    GENERIC MAP (data_pin => " \clock_count22.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count22.D\, CLK => \clock_count22.CLK\, CLRN => \clock_count22.CLRN\,
          PRN => \clock_count22.PRN\, Q => clock_count22_Q);
inv_443: \clock_count22.PRN\  <= TRANSPORT NOT gnd;
inv_444: \clock_count22.CLRN\  <= TRANSPORT NOT gnd;
xor2_445: \clock_count22.D\ <=  n_624  XOR n_589;
or1_446: n_624 <=  n_625;
and2_447: n_625 <= TRANSPORT  n_626  AND n_628 AFTER 5 ns;
inv_448: n_626  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder2|result_node6.OUT\ AFTER 1 ns;
inv_449: n_628  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_450: n_629  <= TRANSPORT n_591;
filter_451: FILTER_test5
    GENERIC MAP (inst_name => "filter_451", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_629, Y => \clock_count22.CLK\);
delay_452: \|lpm_add_sub:2384|addcore:adder2|result_node6.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node6.IN\ AFTER 2 ns;
xor2_453: \|lpm_add_sub:2384|addcore:adder2|result_node6.IN\ <=  n_632  XOR n_635;
or1_454: n_632 <=  n_633;
and1_455: n_633 <= TRANSPORT  n_634 AFTER 5 ns;
delay_456: n_634  <= TRANSPORT clock_count22_Q AFTER 1 ns;
and7_457: n_635 <= TRANSPORT  n_636  AND n_637  AND n_638  AND n_639  AND n_640
           AND n_641  AND n_642 AFTER 5 ns;
delay_458: n_636  <= TRANSPORT clock_count21_Q AFTER 1 ns;
delay_459: n_637  <= TRANSPORT clock_count20_Q AFTER 1 ns;
delay_460: n_638  <= TRANSPORT clock_count19_Q AFTER 1 ns;
delay_461: n_639  <= TRANSPORT clock_count18_Q AFTER 1 ns;
delay_462: n_640  <= TRANSPORT clock_count17_Q AFTER 1 ns;
delay_463: n_641  <= TRANSPORT clock_count16_Q AFTER 1 ns;
delay_464: n_642  <= TRANSPORT \|lpm_add_sub:2384|look_add:look_aheader|:42.OUT\ AFTER 1 ns;
dff_465: DFF_test5
    GENERIC MAP (data_pin => " \clock_count21.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count21.D\, CLK => \clock_count21.CLK\, CLRN => \clock_count21.CLRN\,
          PRN => \clock_count21.PRN\, Q => clock_count21_Q);
inv_466: \clock_count21.PRN\  <= TRANSPORT NOT gnd;
inv_467: \clock_count21.CLRN\  <= TRANSPORT NOT gnd;
xor2_468: \clock_count21.D\ <=  n_650  XOR n_655;
or1_469: n_650 <=  n_651;
and2_470: n_651 <= TRANSPORT  n_652  AND n_654 AFTER 5 ns;
inv_471: n_652  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder2|result_node5.OUT\ AFTER 1 ns;
inv_472: n_654  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
and1_473: n_655 <= TRANSPORT  n_656 AFTER 5 ns;
inv_474: n_656  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
and1_475: n_657 <= TRANSPORT  n_658 AFTER 5 ns;
delay_476: n_658  <= TRANSPORT halved_crystal_Q AFTER 1 ns;
delay_477: n_659  <= TRANSPORT n_657;
filter_478: FILTER_test5
    GENERIC MAP (inst_name => "filter_478", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_659, Y => \clock_count21.CLK\);
delay_479: \|lpm_add_sub:2384|addcore:adder2|result_node5.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node5.IN\ AFTER 2 ns;
xor2_480: \|lpm_add_sub:2384|addcore:adder2|result_node5.IN\ <=  n_662  XOR n_665;
or1_481: n_662 <=  n_663;
and1_482: n_663 <= TRANSPORT  n_664 AFTER 5 ns;
delay_483: n_664  <= TRANSPORT clock_count21_Q AFTER 1 ns;
and6_484: n_665 <= TRANSPORT  n_666  AND n_667  AND n_668  AND n_669  AND n_670
           AND n_671 AFTER 5 ns;
delay_485: n_666  <= TRANSPORT clock_count20_Q AFTER 1 ns;
delay_486: n_667  <= TRANSPORT clock_count19_Q AFTER 1 ns;
delay_487: n_668  <= TRANSPORT clock_count18_Q AFTER 1 ns;
delay_488: n_669  <= TRANSPORT clock_count17_Q AFTER 1 ns;
delay_489: n_670  <= TRANSPORT clock_count16_Q AFTER 1 ns;
delay_490: n_671  <= TRANSPORT \|lpm_add_sub:2384|look_add:look_aheader|:42.OUT\ AFTER 1 ns;
dff_491: DFF_test5
    GENERIC MAP (data_pin => " \clock_count20.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count20.D\, CLK => \clock_count20.CLK\, CLRN => \clock_count20.CLRN\,
          PRN => \clock_count20.PRN\, Q => clock_count20_Q);
inv_492: \clock_count20.PRN\  <= TRANSPORT NOT gnd;
inv_493: \clock_count20.CLRN\  <= TRANSPORT NOT gnd;
xor2_494: \clock_count20.D\ <=  n_679  XOR n_684;
or1_495: n_679 <=  n_680;
and2_496: n_680 <= TRANSPORT  n_681  AND n_682 AFTER 5 ns;
delay_497: n_681  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_498: n_682  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node4.OUT\ AFTER 1 ns;
and1_499: n_684 <= TRANSPORT  n_685 AFTER 5 ns;
delay_500: n_685  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node4.OUT\ AFTER 1 ns;
and1_501: n_686 <= TRANSPORT  n_687 AFTER 5 ns;
delay_502: n_687  <= TRANSPORT halved_crystal_Q AFTER 1 ns;
delay_503: n_688  <= TRANSPORT n_686;
filter_504: FILTER_test5
    GENERIC MAP (inst_name => "filter_504", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_688, Y => \clock_count20.CLK\);
delay_505: \|lpm_add_sub:2384|addcore:adder2|result_node4.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node4.IN\ AFTER 2 ns;
xor2_506: \|lpm_add_sub:2384|addcore:adder2|result_node4.IN\ <=  n_691  XOR n_694;
or1_507: n_691 <=  n_692;
and1_508: n_692 <= TRANSPORT  n_693 AFTER 5 ns;
delay_509: n_693  <= TRANSPORT clock_count20_Q AFTER 1 ns;
and5_510: n_694 <= TRANSPORT  n_695  AND n_696  AND n_697  AND n_698  AND n_699 AFTER 5 ns;
delay_511: n_695  <= TRANSPORT clock_count19_Q AFTER 1 ns;
delay_512: n_696  <= TRANSPORT clock_count18_Q AFTER 1 ns;
delay_513: n_697  <= TRANSPORT clock_count17_Q AFTER 1 ns;
delay_514: n_698  <= TRANSPORT clock_count16_Q AFTER 1 ns;
delay_515: n_699  <= TRANSPORT \|lpm_add_sub:2384|look_add:look_aheader|:42.OUT\ AFTER 1 ns;
dff_516: DFF_test5
    GENERIC MAP (data_pin => " \clock_count19.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count19.D\, CLK => \clock_count19.CLK\, CLRN => \clock_count19.CLRN\,
          PRN => \clock_count19.PRN\, Q => clock_count19_Q);
inv_517: \clock_count19.PRN\  <= TRANSPORT NOT gnd;
inv_518: \clock_count19.CLRN\  <= TRANSPORT NOT gnd;
xor2_519: \clock_count19.D\ <=  n_707  XOR n_712;
or1_520: n_707 <=  n_708;
and2_521: n_708 <= TRANSPORT  n_709  AND n_710 AFTER 5 ns;
delay_522: n_709  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_523: n_710  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node3.OUT\ AFTER 1 ns;
and1_524: n_712 <= TRANSPORT  n_713 AFTER 5 ns;
delay_525: n_713  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node3.OUT\ AFTER 1 ns;
delay_526: n_714  <= TRANSPORT n_686;
filter_527: FILTER_test5
    GENERIC MAP (inst_name => "filter_527", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_714, Y => \clock_count19.CLK\);
delay_528: \|lpm_add_sub:2384|addcore:adder2|result_node3.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node3.IN\ AFTER 2 ns;
xor2_529: \|lpm_add_sub:2384|addcore:adder2|result_node3.IN\ <=  n_717  XOR n_720;
or1_530: n_717 <=  n_718;
and1_531: n_718 <= TRANSPORT  n_719 AFTER 5 ns;
delay_532: n_719  <= TRANSPORT clock_count19_Q AFTER 1 ns;
and4_533: n_720 <= TRANSPORT  n_721  AND n_722  AND n_723  AND n_724 AFTER 5 ns;
delay_534: n_721  <= TRANSPORT clock_count18_Q AFTER 1 ns;
delay_535: n_722  <= TRANSPORT clock_count17_Q AFTER 1 ns;
delay_536: n_723  <= TRANSPORT clock_count16_Q AFTER 1 ns;
delay_537: n_724  <= TRANSPORT \|lpm_add_sub:2384|look_add:look_aheader|:42.OUT\ AFTER 1 ns;
dff_538: DFF_test5
    GENERIC MAP (data_pin => " \clock_count18.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count18.D\, CLK => \clock_count18.CLK\, CLRN => \clock_count18.CLRN\,
          PRN => \clock_count18.PRN\, Q => clock_count18_Q);
inv_539: \clock_count18.PRN\  <= TRANSPORT NOT gnd;
inv_540: \clock_count18.CLRN\  <= TRANSPORT NOT gnd;
xor2_541: \clock_count18.D\ <=  n_732  XOR n_737;
or1_542: n_732 <=  n_733;
and2_543: n_733 <= TRANSPORT  n_734  AND n_735 AFTER 5 ns;
delay_544: n_734  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_545: n_735  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node2.OUT\ AFTER 1 ns;
and1_546: n_737 <= TRANSPORT  n_738 AFTER 5 ns;
delay_547: n_738  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node2.OUT\ AFTER 1 ns;
delay_548: n_739  <= TRANSPORT n_686;
filter_549: FILTER_test5
    GENERIC MAP (inst_name => "filter_549", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_739, Y => \clock_count18.CLK\);
delay_550: \|lpm_add_sub:2384|addcore:adder2|result_node2.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node2.IN\ AFTER 2 ns;
xor2_551: \|lpm_add_sub:2384|addcore:adder2|result_node2.IN\ <=  n_742  XOR n_745;
or1_552: n_742 <=  n_743;
and1_553: n_743 <= TRANSPORT  n_744 AFTER 5 ns;
delay_554: n_744  <= TRANSPORT clock_count18_Q AFTER 1 ns;
and3_555: n_745 <= TRANSPORT  n_746  AND n_747  AND n_748 AFTER 5 ns;
delay_556: n_746  <= TRANSPORT clock_count17_Q AFTER 1 ns;
delay_557: n_747  <= TRANSPORT clock_count16_Q AFTER 1 ns;
delay_558: n_748  <= TRANSPORT \|lpm_add_sub:2384|look_add:look_aheader|:42.OUT\ AFTER 1 ns;
dff_559: DFF_test5
    GENERIC MAP (data_pin => " \clock_count17.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count17.D\, CLK => \clock_count17.CLK\, CLRN => \clock_count17.CLRN\,
          PRN => \clock_count17.PRN\, Q => clock_count17_Q);
inv_560: \clock_count17.PRN\  <= TRANSPORT NOT gnd;
inv_561: \clock_count17.CLRN\  <= TRANSPORT NOT gnd;
xor2_562: \clock_count17.D\ <=  n_756  XOR n_761;
or1_563: n_756 <=  n_757;
and2_564: n_757 <= TRANSPORT  n_758  AND n_759 AFTER 5 ns;
delay_565: n_758  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_566: n_759  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node1.OUT\ AFTER 1 ns;
and1_567: n_761 <= TRANSPORT  n_762 AFTER 5 ns;
delay_568: n_762  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node1.OUT\ AFTER 1 ns;
and1_569: n_763 <= TRANSPORT  n_764 AFTER 5 ns;
delay_570: n_764  <= TRANSPORT halved_crystal_Q AFTER 1 ns;
delay_571: n_765  <= TRANSPORT n_763;
filter_572: FILTER_test5
    GENERIC MAP (inst_name => "filter_572", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_765, Y => \clock_count17.CLK\);
delay_573: \|lpm_add_sub:2384|addcore:adder2|result_node1.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node1.IN\ AFTER 2 ns;
xor2_574: \|lpm_add_sub:2384|addcore:adder2|result_node1.IN\ <=  n_768  XOR n_773;
or1_575: n_768 <=  n_769;
and1_576: n_769 <= TRANSPORT  n_770 AFTER 5 ns;
delay_577: n_770  <= TRANSPORT clock_count17_Q AFTER 1 ns;
and2_578: n_773 <= TRANSPORT  n_771  AND n_772 AFTER 5 ns;
and16_579: n_771 <=  n_774  AND n_775  AND n_777  AND n_779  AND n_781  AND n_783
           AND n_785  AND n_787  AND n_789  AND n_791  AND n_793  AND n_795
           AND n_797  AND n_799  AND n_801  AND n_803;
and1_580: n_772 <=  n_805;
delay_581: n_774  <= TRANSPORT clock_count16_Q AFTER 1 ns;
delay_582: n_775  <= TRANSPORT clock_count15_Q AFTER 1 ns;
delay_583: n_777  <= TRANSPORT clock_count14_Q AFTER 1 ns;
delay_584: n_779  <= TRANSPORT clock_count13_Q AFTER 1 ns;
delay_585: n_781  <= TRANSPORT clock_count12_Q AFTER 1 ns;
delay_586: n_783  <= TRANSPORT clock_count11_Q AFTER 1 ns;
delay_587: n_785  <= TRANSPORT clock_count10_Q AFTER 1 ns;
delay_588: n_787  <= TRANSPORT clock_count9_Q AFTER 1 ns;
delay_589: n_789  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_590: n_791  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_591: n_793  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_592: n_795  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_593: n_797  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_594: n_799  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_595: n_801  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_596: n_803  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_597: n_805  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_598: DFF_test5
    GENERIC MAP (data_pin => " \clock_count16.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count16.D\, CLK => \clock_count16.CLK\, CLRN => \clock_count16.CLRN\,
          PRN => \clock_count16.PRN\, Q => clock_count16_Q);
inv_599: \clock_count16.PRN\  <= TRANSPORT NOT gnd;
inv_600: \clock_count16.CLRN\  <= TRANSPORT NOT gnd;
xor2_601: \clock_count16.D\ <=  n_814  XOR n_819;
or1_602: n_814 <=  n_815;
and2_603: n_815 <= TRANSPORT  n_816  AND n_817 AFTER 5 ns;
delay_604: n_816  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_605: n_817  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node0.OUT\ AFTER 1 ns;
and1_606: n_819 <= TRANSPORT  n_820 AFTER 5 ns;
delay_607: n_820  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node0.OUT\ AFTER 1 ns;
delay_608: n_821  <= TRANSPORT n_763;
filter_609: FILTER_test5
    GENERIC MAP (inst_name => "filter_609", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_821, Y => \clock_count16.CLK\);
delay_610: \|lpm_add_sub:2384|addcore:adder2|result_node0.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder2|result_node0.IN\ AFTER 2 ns;
xor2_611: \|lpm_add_sub:2384|addcore:adder2|result_node0.IN\ <=  n_824  XOR n_827;
or1_612: n_824 <=  n_825;
and1_613: n_825 <= TRANSPORT  n_826 AFTER 5 ns;
delay_614: n_826  <= TRANSPORT clock_count16_Q AFTER 1 ns;
and16_615: n_827 <= TRANSPORT  n_828  AND n_829  AND n_830  AND n_831  AND n_832
           AND n_833  AND n_834  AND n_835  AND n_836  AND n_837  AND n_838
           AND n_839  AND n_840  AND n_841  AND n_842  AND n_843 AFTER 5 ns;
delay_616: n_828  <= TRANSPORT clock_count15_Q AFTER 1 ns;
delay_617: n_829  <= TRANSPORT clock_count14_Q AFTER 1 ns;
delay_618: n_830  <= TRANSPORT clock_count13_Q AFTER 1 ns;
delay_619: n_831  <= TRANSPORT clock_count12_Q AFTER 1 ns;
delay_620: n_832  <= TRANSPORT clock_count11_Q AFTER 1 ns;
delay_621: n_833  <= TRANSPORT clock_count10_Q AFTER 1 ns;
delay_622: n_834  <= TRANSPORT clock_count9_Q AFTER 1 ns;
delay_623: n_835  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_624: n_836  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_625: n_837  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_626: n_838  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_627: n_839  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_628: n_840  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_629: n_841  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_630: n_842  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_631: n_843  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_632: DFF_test5
    GENERIC MAP (data_pin => " \clock_count15.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count15.D\, CLK => \clock_count15.CLK\, CLRN => \clock_count15.CLRN\,
          PRN => \clock_count15.PRN\, Q => clock_count15_Q);
inv_633: \clock_count15.PRN\  <= TRANSPORT NOT gnd;
inv_634: \clock_count15.CLRN\  <= TRANSPORT NOT gnd;
xor2_635: \clock_count15.D\ <=  n_851  XOR n_856;
or1_636: n_851 <=  n_852;
and2_637: n_852 <= TRANSPORT  n_853  AND n_855 AFTER 5 ns;
inv_638: n_853  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder1|result_node7.OUT\ AFTER 1 ns;
inv_639: n_855  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
and1_640: n_856 <= TRANSPORT  n_857 AFTER 5 ns;
inv_641: n_857  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_642: n_858  <= TRANSPORT n_763;
filter_643: FILTER_test5
    GENERIC MAP (inst_name => "filter_643", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_858, Y => \clock_count15.CLK\);
delay_644: \|lpm_add_sub:2384|addcore:adder1|result_node7.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node7.IN\ AFTER 2 ns;
xor2_645: \|lpm_add_sub:2384|addcore:adder1|result_node7.IN\ <=  n_861  XOR n_864;
or1_646: n_861 <=  n_862;
and1_647: n_862 <= TRANSPORT  n_863 AFTER 5 ns;
delay_648: n_863  <= TRANSPORT clock_count15_Q AFTER 1 ns;
and15_649: n_864 <= TRANSPORT  n_865  AND n_866  AND n_867  AND n_868  AND n_869
           AND n_870  AND n_871  AND n_872  AND n_873  AND n_874  AND n_875
           AND n_876  AND n_877  AND n_878  AND n_879 AFTER 5 ns;
delay_650: n_865  <= TRANSPORT clock_count14_Q AFTER 1 ns;
delay_651: n_866  <= TRANSPORT clock_count13_Q AFTER 1 ns;
delay_652: n_867  <= TRANSPORT clock_count12_Q AFTER 1 ns;
delay_653: n_868  <= TRANSPORT clock_count11_Q AFTER 1 ns;
delay_654: n_869  <= TRANSPORT clock_count10_Q AFTER 1 ns;
delay_655: n_870  <= TRANSPORT clock_count9_Q AFTER 1 ns;
delay_656: n_871  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_657: n_872  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_658: n_873  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_659: n_874  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_660: n_875  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_661: n_876  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_662: n_877  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_663: n_878  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_664: n_879  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_665: DFF_test5
    GENERIC MAP (data_pin => " \clock_count14.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count14.D\, CLK => \clock_count14.CLK\, CLRN => \clock_count14.CLRN\,
          PRN => \clock_count14.PRN\, Q => clock_count14_Q);
inv_666: \clock_count14.PRN\  <= TRANSPORT NOT gnd;
inv_667: \clock_count14.CLRN\  <= TRANSPORT NOT gnd;
xor2_668: \clock_count14.D\ <=  n_887  XOR n_856;
or1_669: n_887 <=  n_888;
and2_670: n_888 <= TRANSPORT  n_889  AND n_891 AFTER 5 ns;
inv_671: n_889  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder1|result_node6.OUT\ AFTER 1 ns;
inv_672: n_891  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_673: n_892  <= TRANSPORT n_763;
filter_674: FILTER_test5
    GENERIC MAP (inst_name => "filter_674", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_892, Y => \clock_count14.CLK\);
delay_675: \|lpm_add_sub:2384|addcore:adder1|result_node6.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node6.IN\ AFTER 2 ns;
xor2_676: \|lpm_add_sub:2384|addcore:adder1|result_node6.IN\ <=  n_895  XOR n_898;
or1_677: n_895 <=  n_896;
and1_678: n_896 <= TRANSPORT  n_897 AFTER 5 ns;
delay_679: n_897  <= TRANSPORT clock_count14_Q AFTER 1 ns;
and14_680: n_898 <= TRANSPORT  n_899  AND n_900  AND n_901  AND n_902  AND n_903
           AND n_904  AND n_905  AND n_906  AND n_907  AND n_908  AND n_909
           AND n_910  AND n_911  AND n_912 AFTER 5 ns;
delay_681: n_899  <= TRANSPORT clock_count13_Q AFTER 1 ns;
delay_682: n_900  <= TRANSPORT clock_count12_Q AFTER 1 ns;
delay_683: n_901  <= TRANSPORT clock_count11_Q AFTER 1 ns;
delay_684: n_902  <= TRANSPORT clock_count10_Q AFTER 1 ns;
delay_685: n_903  <= TRANSPORT clock_count9_Q AFTER 1 ns;
delay_686: n_904  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_687: n_905  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_688: n_906  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_689: n_907  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_690: n_908  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_691: n_909  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_692: n_910  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_693: n_911  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_694: n_912  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_695: DFF_test5
    GENERIC MAP (data_pin => " \clock_count13.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count13.D\, CLK => \clock_count13.CLK\, CLRN => \clock_count13.CLRN\,
          PRN => \clock_count13.PRN\, Q => clock_count13_Q);
inv_696: \clock_count13.PRN\  <= TRANSPORT NOT gnd;
inv_697: \clock_count13.CLRN\  <= TRANSPORT NOT gnd;
xor2_698: \clock_count13.D\ <=  n_920  XOR n_856;
or1_699: n_920 <=  n_921;
and2_700: n_921 <= TRANSPORT  n_922  AND n_924 AFTER 5 ns;
inv_701: n_922  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder1|result_node5.OUT\ AFTER 1 ns;
inv_702: n_924  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_703: n_925  <= TRANSPORT n_763;
filter_704: FILTER_test5
    GENERIC MAP (inst_name => "filter_704", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_925, Y => \clock_count13.CLK\);
delay_705: \|lpm_add_sub:2384|addcore:adder1|result_node5.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node5.IN\ AFTER 2 ns;
xor2_706: \|lpm_add_sub:2384|addcore:adder1|result_node5.IN\ <=  n_928  XOR n_931;
or1_707: n_928 <=  n_929;
and1_708: n_929 <= TRANSPORT  n_930 AFTER 5 ns;
delay_709: n_930  <= TRANSPORT clock_count13_Q AFTER 1 ns;
and13_710: n_931 <= TRANSPORT  n_932  AND n_933  AND n_934  AND n_935  AND n_936
           AND n_937  AND n_938  AND n_939  AND n_940  AND n_941  AND n_942
           AND n_943  AND n_944 AFTER 5 ns;
delay_711: n_932  <= TRANSPORT clock_count12_Q AFTER 1 ns;
delay_712: n_933  <= TRANSPORT clock_count11_Q AFTER 1 ns;
delay_713: n_934  <= TRANSPORT clock_count10_Q AFTER 1 ns;
delay_714: n_935  <= TRANSPORT clock_count9_Q AFTER 1 ns;
delay_715: n_936  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_716: n_937  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_717: n_938  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_718: n_939  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_719: n_940  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_720: n_941  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_721: n_942  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_722: n_943  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_723: n_944  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_724: DFF_test5
    GENERIC MAP (data_pin => " \clock_count12.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count12.D\, CLK => \clock_count12.CLK\, CLRN => \clock_count12.CLRN\,
          PRN => \clock_count12.PRN\, Q => clock_count12_Q);
inv_725: \clock_count12.PRN\  <= TRANSPORT NOT gnd;
inv_726: \clock_count12.CLRN\  <= TRANSPORT NOT gnd;
xor2_727: \clock_count12.D\ <=  n_952  XOR n_957;
or1_728: n_952 <=  n_953;
and2_729: n_953 <= TRANSPORT  n_954  AND n_955 AFTER 5 ns;
delay_730: n_954  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_731: n_955  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node4.OUT\ AFTER 1 ns;
and1_732: n_957 <= TRANSPORT  n_958 AFTER 5 ns;
delay_733: n_958  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node4.OUT\ AFTER 1 ns;
delay_734: n_959  <= TRANSPORT n_763;
filter_735: FILTER_test5
    GENERIC MAP (inst_name => "filter_735", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_959, Y => \clock_count12.CLK\);
delay_736: \|lpm_add_sub:2384|addcore:adder1|result_node4.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node4.IN\ AFTER 2 ns;
xor2_737: \|lpm_add_sub:2384|addcore:adder1|result_node4.IN\ <=  n_962  XOR n_965;
or1_738: n_962 <=  n_963;
and1_739: n_963 <= TRANSPORT  n_964 AFTER 5 ns;
delay_740: n_964  <= TRANSPORT clock_count12_Q AFTER 1 ns;
and12_741: n_965 <= TRANSPORT  n_966  AND n_967  AND n_968  AND n_969  AND n_970
           AND n_971  AND n_972  AND n_973  AND n_974  AND n_975  AND n_976
           AND n_977 AFTER 5 ns;
delay_742: n_966  <= TRANSPORT clock_count11_Q AFTER 1 ns;
delay_743: n_967  <= TRANSPORT clock_count10_Q AFTER 1 ns;
delay_744: n_968  <= TRANSPORT clock_count9_Q AFTER 1 ns;
delay_745: n_969  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_746: n_970  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_747: n_971  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_748: n_972  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_749: n_973  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_750: n_974  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_751: n_975  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_752: n_976  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_753: n_977  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_754: DFF_test5
    GENERIC MAP (data_pin => " \clock_count11.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count11.D\, CLK => \clock_count11.CLK\, CLRN => \clock_count11.CLRN\,
          PRN => \clock_count11.PRN\, Q => clock_count11_Q);
inv_755: \clock_count11.PRN\  <= TRANSPORT NOT gnd;
inv_756: \clock_count11.CLRN\  <= TRANSPORT NOT gnd;
xor2_757: \clock_count11.D\ <=  n_985  XOR n_990;
or1_758: n_985 <=  n_986;
and2_759: n_986 <= TRANSPORT  n_987  AND n_988 AFTER 5 ns;
delay_760: n_987  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_761: n_988  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node3.OUT\ AFTER 1 ns;
and1_762: n_990 <= TRANSPORT  n_991 AFTER 5 ns;
delay_763: n_991  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node3.OUT\ AFTER 1 ns;
delay_764: n_992  <= TRANSPORT n_763;
filter_765: FILTER_test5
    GENERIC MAP (inst_name => "filter_765", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_992, Y => \clock_count11.CLK\);
delay_766: \|lpm_add_sub:2384|addcore:adder1|result_node3.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node3.IN\ AFTER 2 ns;
xor2_767: \|lpm_add_sub:2384|addcore:adder1|result_node3.IN\ <=  n_995  XOR n_998;
or1_768: n_995 <=  n_996;
and1_769: n_996 <= TRANSPORT  n_997 AFTER 5 ns;
delay_770: n_997  <= TRANSPORT clock_count11_Q AFTER 1 ns;
and11_771: n_998 <= TRANSPORT  n_999  AND n_1000  AND n_1001  AND n_1002
           AND n_1003  AND n_1004  AND n_1005  AND n_1006  AND n_1007  AND n_1008
           AND n_1009 AFTER 5 ns;
delay_772: n_999  <= TRANSPORT clock_count10_Q AFTER 1 ns;
delay_773: n_1000  <= TRANSPORT clock_count9_Q AFTER 1 ns;
delay_774: n_1001  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_775: n_1002  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_776: n_1003  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_777: n_1004  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_778: n_1005  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_779: n_1006  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_780: n_1007  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_781: n_1008  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_782: n_1009  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_783: DFF_test5
    GENERIC MAP (data_pin => " \clock_count10.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count10.D\, CLK => \clock_count10.CLK\, CLRN => \clock_count10.CLRN\,
          PRN => \clock_count10.PRN\, Q => clock_count10_Q);
inv_784: \clock_count10.PRN\  <= TRANSPORT NOT gnd;
inv_785: \clock_count10.CLRN\  <= TRANSPORT NOT gnd;
xor2_786: \clock_count10.D\ <=  n_1017  XOR n_1022;
or1_787: n_1017 <=  n_1018;
and2_788: n_1018 <= TRANSPORT  n_1019  AND n_1020 AFTER 5 ns;
delay_789: n_1019  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_790: n_1020  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node2.OUT\ AFTER 1 ns;
and1_791: n_1022 <= TRANSPORT  n_1023 AFTER 5 ns;
delay_792: n_1023  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node2.OUT\ AFTER 1 ns;
delay_793: n_1024  <= TRANSPORT n_763;
filter_794: FILTER_test5
    GENERIC MAP (inst_name => "filter_794", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1024, Y => \clock_count10.CLK\);
delay_795: \|lpm_add_sub:2384|addcore:adder1|result_node2.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node2.IN\ AFTER 2 ns;
xor2_796: \|lpm_add_sub:2384|addcore:adder1|result_node2.IN\ <=  n_1027  XOR n_1030;
or1_797: n_1027 <=  n_1028;
and1_798: n_1028 <= TRANSPORT  n_1029 AFTER 5 ns;
delay_799: n_1029  <= TRANSPORT clock_count10_Q AFTER 1 ns;
and10_800: n_1030 <= TRANSPORT  n_1031  AND n_1032  AND n_1033  AND n_1034
           AND n_1035  AND n_1036  AND n_1037  AND n_1038  AND n_1039  AND n_1040 AFTER 5 ns;
delay_801: n_1031  <= TRANSPORT clock_count9_Q AFTER 1 ns;
delay_802: n_1032  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_803: n_1033  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_804: n_1034  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_805: n_1035  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_806: n_1036  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_807: n_1037  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_808: n_1038  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_809: n_1039  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_810: n_1040  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_811: DFF_test5
    GENERIC MAP (data_pin => " \clock_count9.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count9.D\, CLK => \clock_count9.CLK\, CLRN => \clock_count9.CLRN\,
          PRN => \clock_count9.PRN\, Q => clock_count9_Q);
inv_812: \clock_count9.PRN\  <= TRANSPORT NOT gnd;
inv_813: \clock_count9.CLRN\  <= TRANSPORT NOT gnd;
xor2_814: \clock_count9.D\ <=  n_1048  XOR n_1053;
or1_815: n_1048 <=  n_1049;
and2_816: n_1049 <= TRANSPORT  n_1050  AND n_1051 AFTER 5 ns;
delay_817: n_1050  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_818: n_1051  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node1.OUT\ AFTER 1 ns;
and1_819: n_1053 <= TRANSPORT  n_1054 AFTER 5 ns;
delay_820: n_1054  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node1.OUT\ AFTER 1 ns;
delay_821: n_1055  <= TRANSPORT n_763;
filter_822: FILTER_test5
    GENERIC MAP (inst_name => "filter_822", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1055, Y => \clock_count9.CLK\);
delay_823: \|lpm_add_sub:2384|addcore:adder1|result_node1.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node1.IN\ AFTER 2 ns;
xor2_824: \|lpm_add_sub:2384|addcore:adder1|result_node1.IN\ <=  n_1058  XOR n_1061;
or1_825: n_1058 <=  n_1059;
and1_826: n_1059 <= TRANSPORT  n_1060 AFTER 5 ns;
delay_827: n_1060  <= TRANSPORT clock_count9_Q AFTER 1 ns;
and9_828: n_1061 <= TRANSPORT  n_1062  AND n_1063  AND n_1064  AND n_1065
           AND n_1066  AND n_1067  AND n_1068  AND n_1069  AND n_1070 AFTER 5 ns;
delay_829: n_1062  <= TRANSPORT clock_count8_Q AFTER 1 ns;
delay_830: n_1063  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_831: n_1064  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_832: n_1065  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_833: n_1066  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_834: n_1067  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_835: n_1068  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_836: n_1069  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_837: n_1070  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_838: DFF_test5
    GENERIC MAP (data_pin => " \clock_count8.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count8.D\, CLK => \clock_count8.CLK\, CLRN => \clock_count8.CLRN\,
          PRN => \clock_count8.PRN\, Q => clock_count8_Q);
inv_839: \clock_count8.PRN\  <= TRANSPORT NOT gnd;
inv_840: \clock_count8.CLRN\  <= TRANSPORT NOT gnd;
xor2_841: \clock_count8.D\ <=  n_1078  XOR n_1083;
or1_842: n_1078 <=  n_1079;
and2_843: n_1079 <= TRANSPORT  n_1080  AND n_1081 AFTER 5 ns;
delay_844: n_1080  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_845: n_1081  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node0.OUT\ AFTER 1 ns;
and1_846: n_1083 <= TRANSPORT  n_1084 AFTER 5 ns;
delay_847: n_1084  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node0.OUT\ AFTER 1 ns;
and1_848: n_1085 <= TRANSPORT  n_1086 AFTER 5 ns;
delay_849: n_1086  <= TRANSPORT halved_crystal_Q AFTER 1 ns;
delay_850: n_1087  <= TRANSPORT n_1085;
filter_851: FILTER_test5
    GENERIC MAP (inst_name => "filter_851", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1087, Y => \clock_count8.CLK\);
delay_852: \|lpm_add_sub:2384|addcore:adder1|result_node0.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder1|result_node0.IN\ AFTER 2 ns;
xor2_853: \|lpm_add_sub:2384|addcore:adder1|result_node0.IN\ <=  n_1090  XOR n_1093;
or1_854: n_1090 <=  n_1091;
and1_855: n_1091 <= TRANSPORT  n_1092 AFTER 5 ns;
delay_856: n_1092  <= TRANSPORT clock_count8_Q AFTER 1 ns;
and8_857: n_1093 <= TRANSPORT  n_1094  AND n_1095  AND n_1096  AND n_1097
           AND n_1098  AND n_1099  AND n_1100  AND n_1101 AFTER 5 ns;
delay_858: n_1094  <= TRANSPORT clock_count7_Q AFTER 1 ns;
delay_859: n_1095  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_860: n_1096  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_861: n_1097  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_862: n_1098  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_863: n_1099  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_864: n_1100  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_865: n_1101  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_866: DFF_test5
    GENERIC MAP (data_pin => " \clock_count7.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count7.D\, CLK => \clock_count7.CLK\, CLRN => \clock_count7.CLRN\,
          PRN => \clock_count7.PRN\, Q => clock_count7_Q);
inv_867: \clock_count7.PRN\  <= TRANSPORT NOT gnd;
inv_868: \clock_count7.CLRN\  <= TRANSPORT NOT gnd;
xor2_869: \clock_count7.D\ <=  n_1109  XOR n_1114;
or1_870: n_1109 <=  n_1110;
and2_871: n_1110 <= TRANSPORT  n_1111  AND n_1113 AFTER 5 ns;
inv_872: n_1111  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder0|result_node7.OUT\ AFTER 1 ns;
inv_873: n_1113  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
and1_874: n_1114 <= TRANSPORT  n_1115 AFTER 5 ns;
inv_875: n_1115  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_876: n_1116  <= TRANSPORT n_1085;
filter_877: FILTER_test5
    GENERIC MAP (inst_name => "filter_877", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1116, Y => \clock_count7.CLK\);
delay_878: \|lpm_add_sub:2384|addcore:adder0|result_node7.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node7.IN\ AFTER 2 ns;
xor2_879: \|lpm_add_sub:2384|addcore:adder0|result_node7.IN\ <=  n_1119  XOR n_1122;
or1_880: n_1119 <=  n_1120;
and1_881: n_1120 <= TRANSPORT  n_1121 AFTER 5 ns;
delay_882: n_1121  <= TRANSPORT clock_count7_Q AFTER 1 ns;
and7_883: n_1122 <= TRANSPORT  n_1123  AND n_1124  AND n_1125  AND n_1126
           AND n_1127  AND n_1128  AND n_1129 AFTER 5 ns;
delay_884: n_1123  <= TRANSPORT clock_count6_Q AFTER 1 ns;
delay_885: n_1124  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_886: n_1125  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_887: n_1126  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_888: n_1127  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_889: n_1128  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_890: n_1129  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_891: DFF_test5
    GENERIC MAP (data_pin => " \clock_count6.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count6.D\, CLK => \clock_count6.CLK\, CLRN => \clock_count6.CLRN\,
          PRN => \clock_count6.PRN\, Q => clock_count6_Q);
inv_892: \clock_count6.PRN\  <= TRANSPORT NOT gnd;
inv_893: \clock_count6.CLRN\  <= TRANSPORT NOT gnd;
xor2_894: \clock_count6.D\ <=  n_1137  XOR n_1114;
or1_895: n_1137 <=  n_1138;
and2_896: n_1138 <= TRANSPORT  n_1139  AND n_1141 AFTER 5 ns;
inv_897: n_1139  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder0|result_node6.OUT\ AFTER 1 ns;
inv_898: n_1141  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_899: n_1142  <= TRANSPORT n_1085;
filter_900: FILTER_test5
    GENERIC MAP (inst_name => "filter_900", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1142, Y => \clock_count6.CLK\);
delay_901: \|lpm_add_sub:2384|addcore:adder0|result_node6.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node6.IN\ AFTER 2 ns;
xor2_902: \|lpm_add_sub:2384|addcore:adder0|result_node6.IN\ <=  n_1145  XOR n_1148;
or1_903: n_1145 <=  n_1146;
and1_904: n_1146 <= TRANSPORT  n_1147 AFTER 5 ns;
delay_905: n_1147  <= TRANSPORT clock_count6_Q AFTER 1 ns;
and6_906: n_1148 <= TRANSPORT  n_1149  AND n_1150  AND n_1151  AND n_1152
           AND n_1153  AND n_1154 AFTER 5 ns;
delay_907: n_1149  <= TRANSPORT clock_count5_Q AFTER 1 ns;
delay_908: n_1150  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_909: n_1151  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_910: n_1152  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_911: n_1153  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_912: n_1154  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_913: DFF_test5
    GENERIC MAP (data_pin => " \clock_count5.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count5.D\, CLK => \clock_count5.CLK\, CLRN => \clock_count5.CLRN\,
          PRN => \clock_count5.PRN\, Q => clock_count5_Q);
inv_914: \clock_count5.PRN\  <= TRANSPORT NOT gnd;
inv_915: \clock_count5.CLRN\  <= TRANSPORT NOT gnd;
xor2_916: \clock_count5.D\ <=  n_1162  XOR n_1114;
or1_917: n_1162 <=  n_1163;
and2_918: n_1163 <= TRANSPORT  n_1164  AND n_1166 AFTER 5 ns;
inv_919: n_1164  <= TRANSPORT NOT \|lpm_add_sub:2384|addcore:adder0|result_node5.OUT\ AFTER 1 ns;
inv_920: n_1166  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_921: n_1167  <= TRANSPORT n_1085;
filter_922: FILTER_test5
    GENERIC MAP (inst_name => "filter_922", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1167, Y => \clock_count5.CLK\);
delay_923: \|lpm_add_sub:2384|addcore:adder0|result_node5.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node5.IN\ AFTER 2 ns;
xor2_924: \|lpm_add_sub:2384|addcore:adder0|result_node5.IN\ <=  n_1170  XOR n_1173;
or1_925: n_1170 <=  n_1171;
and1_926: n_1171 <= TRANSPORT  n_1172 AFTER 5 ns;
delay_927: n_1172  <= TRANSPORT clock_count5_Q AFTER 1 ns;
and5_928: n_1173 <= TRANSPORT  n_1174  AND n_1175  AND n_1176  AND n_1177
           AND n_1178 AFTER 5 ns;
delay_929: n_1174  <= TRANSPORT clock_count4_Q AFTER 1 ns;
delay_930: n_1175  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_931: n_1176  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_932: n_1177  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_933: n_1178  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_934: DFF_test5
    GENERIC MAP (data_pin => " \clock_count4.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count4.D\, CLK => \clock_count4.CLK\, CLRN => \clock_count4.CLRN\,
          PRN => \clock_count4.PRN\, Q => clock_count4_Q);
inv_935: \clock_count4.PRN\  <= TRANSPORT NOT gnd;
inv_936: \clock_count4.CLRN\  <= TRANSPORT NOT gnd;
xor2_937: \clock_count4.D\ <=  n_1186  XOR n_1191;
or1_938: n_1186 <=  n_1187;
and2_939: n_1187 <= TRANSPORT  n_1188  AND n_1189 AFTER 5 ns;
delay_940: n_1188  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_941: n_1189  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node4.OUT\ AFTER 1 ns;
and1_942: n_1191 <= TRANSPORT  n_1192 AFTER 5 ns;
delay_943: n_1192  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node4.OUT\ AFTER 1 ns;
delay_944: n_1193  <= TRANSPORT n_1085;
filter_945: FILTER_test5
    GENERIC MAP (inst_name => "filter_945", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1193, Y => \clock_count4.CLK\);
delay_946: \|lpm_add_sub:2384|addcore:adder0|result_node4.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node4.IN\ AFTER 2 ns;
xor2_947: \|lpm_add_sub:2384|addcore:adder0|result_node4.IN\ <=  n_1196  XOR n_1199;
or1_948: n_1196 <=  n_1197;
and1_949: n_1197 <= TRANSPORT  n_1198 AFTER 5 ns;
delay_950: n_1198  <= TRANSPORT clock_count4_Q AFTER 1 ns;
and4_951: n_1199 <= TRANSPORT  n_1200  AND n_1201  AND n_1202  AND n_1203 AFTER 5 ns;
delay_952: n_1200  <= TRANSPORT clock_count3_Q AFTER 1 ns;
delay_953: n_1201  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_954: n_1202  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_955: n_1203  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_956: DFF_test5
    GENERIC MAP (data_pin => " \clock_count3.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count3.D\, CLK => \clock_count3.CLK\, CLRN => \clock_count3.CLRN\,
          PRN => \clock_count3.PRN\, Q => clock_count3_Q);
inv_957: \clock_count3.PRN\  <= TRANSPORT NOT gnd;
inv_958: \clock_count3.CLRN\  <= TRANSPORT NOT gnd;
xor2_959: \clock_count3.D\ <=  n_1211  XOR n_1216;
or1_960: n_1211 <=  n_1212;
and2_961: n_1212 <= TRANSPORT  n_1213  AND n_1214 AFTER 5 ns;
delay_962: n_1213  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_963: n_1214  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node3.OUT\ AFTER 1 ns;
and1_964: n_1216 <= TRANSPORT  n_1217 AFTER 5 ns;
delay_965: n_1217  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node3.OUT\ AFTER 1 ns;
delay_966: n_1218  <= TRANSPORT n_1085;
filter_967: FILTER_test5
    GENERIC MAP (inst_name => "filter_967", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1218, Y => \clock_count3.CLK\);
delay_968: \|lpm_add_sub:2384|addcore:adder0|result_node3.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node3.IN\ AFTER 2 ns;
xor2_969: \|lpm_add_sub:2384|addcore:adder0|result_node3.IN\ <=  n_1221  XOR n_1224;
or1_970: n_1221 <=  n_1222;
and1_971: n_1222 <= TRANSPORT  n_1223 AFTER 5 ns;
delay_972: n_1223  <= TRANSPORT clock_count3_Q AFTER 1 ns;
and3_973: n_1224 <= TRANSPORT  n_1225  AND n_1226  AND n_1227 AFTER 5 ns;
delay_974: n_1225  <= TRANSPORT clock_count2_Q AFTER 1 ns;
delay_975: n_1226  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_976: n_1227  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_977: DFF_test5
    GENERIC MAP (data_pin => " \clock_count2.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count2.D\, CLK => \clock_count2.CLK\, CLRN => \clock_count2.CLRN\,
          PRN => \clock_count2.PRN\, Q => clock_count2_Q);
inv_978: \clock_count2.PRN\  <= TRANSPORT NOT gnd;
inv_979: \clock_count2.CLRN\  <= TRANSPORT NOT gnd;
xor2_980: \clock_count2.D\ <=  n_1235  XOR n_1240;
or1_981: n_1235 <=  n_1236;
and2_982: n_1236 <= TRANSPORT  n_1237  AND n_1238 AFTER 5 ns;
delay_983: n_1237  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_984: n_1238  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node2.OUT\ AFTER 1 ns;
and1_985: n_1240 <= TRANSPORT  n_1241 AFTER 5 ns;
delay_986: n_1241  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node2.OUT\ AFTER 1 ns;
delay_987: n_1242  <= TRANSPORT n_1085;
filter_988: FILTER_test5
    GENERIC MAP (inst_name => "filter_988", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1242, Y => \clock_count2.CLK\);
delay_989: \|lpm_add_sub:2384|addcore:adder0|result_node2.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node2.IN\ AFTER 2 ns;
xor2_990: \|lpm_add_sub:2384|addcore:adder0|result_node2.IN\ <=  n_1245  XOR n_1248;
or1_991: n_1245 <=  n_1246;
and1_992: n_1246 <= TRANSPORT  n_1247 AFTER 5 ns;
delay_993: n_1247  <= TRANSPORT clock_count2_Q AFTER 1 ns;
and2_994: n_1248 <= TRANSPORT  n_1249  AND n_1250 AFTER 5 ns;
delay_995: n_1249  <= TRANSPORT clock_count1_Q AFTER 1 ns;
delay_996: n_1250  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_997: DFF_test5
    GENERIC MAP (data_pin => " \clock_count1.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count1.D\, CLK => \clock_count1.CLK\, CLRN => \clock_count1.CLRN\,
          PRN => \clock_count1.PRN\, Q => clock_count1_Q);
inv_998: \clock_count1.PRN\  <= TRANSPORT NOT gnd;
inv_999: \clock_count1.CLRN\  <= TRANSPORT NOT gnd;
xor2_1000: \clock_count1.D\ <=  n_1258  XOR n_1263;
or1_1001: n_1258 <=  n_1259;
and2_1002: n_1259 <= TRANSPORT  n_1260  AND n_1261 AFTER 5 ns;
delay_1003: n_1260  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_1004: n_1261  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node1.OUT\ AFTER 1 ns;
and1_1005: n_1263 <= TRANSPORT  n_1264 AFTER 5 ns;
delay_1006: n_1264  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node1.OUT\ AFTER 1 ns;
delay_1007: n_1265  <= TRANSPORT n_1085;
filter_1008: FILTER_test5
    GENERIC MAP (inst_name => "filter_1008", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1265, Y => \clock_count1.CLK\);
delay_1009: \|lpm_add_sub:2384|addcore:adder0|result_node1.OUT\  <= TRANSPORT \|lpm_add_sub:2384|addcore:adder0|result_node1.IN\ AFTER 2 ns;
xor2_1010: \|lpm_add_sub:2384|addcore:adder0|result_node1.IN\ <=  n_1268
           XOR n_1271;
or1_1011: n_1268 <=  n_1269;
and1_1012: n_1269 <= TRANSPORT  n_1270 AFTER 5 ns;
delay_1013: n_1270  <= TRANSPORT clock_count1_Q AFTER 1 ns;
and1_1014: n_1271 <= TRANSPORT  n_1272 AFTER 5 ns;
delay_1015: n_1272  <= TRANSPORT clock_count0_Q AFTER 1 ns;
dff_1016: DFF_test5
    GENERIC MAP (data_pin => " \clock_count0.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \clock_count0.D\, CLK => \clock_count0.CLK\, CLRN => \clock_count0.CLRN\,
          PRN => \clock_count0.PRN\, Q => clock_count0_Q);
inv_1017: \clock_count0.PRN\  <= TRANSPORT NOT gnd;
inv_1018: \clock_count0.CLRN\  <= TRANSPORT NOT gnd;
xor2_1019: \clock_count0.D\ <=  n_1280  XOR n_1284;
or1_1020: n_1280 <=  n_1281;
and2_1021: n_1281 <= TRANSPORT  n_1282  AND n_1283 AFTER 5 ns;
inv_1022: n_1282  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
delay_1023: n_1283  <= TRANSPORT clock_count0_Q AFTER 1 ns;
and1_1024: n_1284 <= TRANSPORT  n_1285 AFTER 5 ns;
inv_1025: n_1285  <= TRANSPORT NOT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
and1_1026: n_1286 <= TRANSPORT  n_1287 AFTER 5 ns;
delay_1027: n_1287  <= TRANSPORT halved_crystal_Q AFTER 1 ns;
delay_1028: n_1288  <= TRANSPORT n_1286;
filter_1029: FILTER_test5
    GENERIC MAP (inst_name => "filter_1029", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1288, Y => \clock_count0.CLK\);
dff_1030: DFF_test5
    GENERIC MAP (data_pin => " \halved_crystal.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \halved_crystal.D\, CLK => \halved_crystal.CLK\, CLRN => \halved_crystal.CLRN\,
          PRN => \halved_crystal.PRN\, Q => halved_crystal_Q);
inv_1031: \halved_crystal.PRN\  <= TRANSPORT NOT gnd;
inv_1032: \halved_crystal.CLRN\  <= TRANSPORT NOT gnd;
xor2_1033: \halved_crystal.D\ <=  \:2139\  XOR n_1286;
or1_1034: \:2139\ <=  n_1298;
and1_1035: n_1298 <= TRANSPORT  vcc AFTER 5 ns;
delay_1036: n_1299  <= TRANSPORT gclk2 AFTER 1500 ps;
filter_1037: FILTER_test5
    GENERIC MAP (inst_name => "filter_1037", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1299, Y => \halved_crystal.CLK\);
delay_1038: \|lpm_add_sub:2384|look_add:look_aheader|:42.OUT\  <= TRANSPORT \|lpm_add_sub:2384|look_add:look_aheader|:42.IN\ AFTER 2 ns;
xor2_1039: \|lpm_add_sub:2384|look_add:look_aheader|:42.IN\ <=  n_1303  XOR n_1304;
or1_1040: n_1303 <=  n_827;
and1_1041: n_1304 <= TRANSPORT  gnd AFTER 5 ns;
delay_1042: \led2~fit~in1\  <= TRANSPORT \:8437\ AFTER 2 ns;
xor2_1043: \:8437\ <=  n_1312  XOR n_1426;
or1_1044: n_1312 <=  n_1313;
and16_1045: n_1313 <= TRANSPORT  n_1314  AND n_1321  AND n_1328  AND n_1335
           AND n_1342  AND n_1349  AND n_1356  AND n_1363  AND n_1370  AND n_1377
           AND n_1384  AND n_1391  AND n_1398  AND n_1405  AND n_1412  AND n_1419 AFTER 5 ns;
inv_1046: n_1314  <= TRANSPORT NOT n_1315;
and5_1047: n_1315 <= TRANSPORT  n_1316  AND n_1317  AND n_1318  AND n_1319
           AND n_1320 AFTER 5 ns;
inv_1048: n_1316  <= TRANSPORT NOT dip(3) AFTER 1500 ps;
inv_1049: n_1317  <= TRANSPORT NOT dip(2) AFTER 1500 ps;
inv_1050: n_1318  <= TRANSPORT NOT dip(1) AFTER 1500 ps;
inv_1051: n_1319  <= TRANSPORT NOT pb1 AFTER 1500 ps;
delay_1052: n_1320  <= TRANSPORT dip(4) AFTER 1500 ps;
inv_1053: n_1321  <= TRANSPORT NOT n_1322;
and5_1054: n_1322 <= TRANSPORT  n_1323  AND n_1324  AND n_1325  AND n_1326
           AND n_1327 AFTER 5 ns;
inv_1055: n_1323  <= TRANSPORT NOT dip(4) AFTER 1500 ps;
inv_1056: n_1324  <= TRANSPORT NOT dip(2) AFTER 1500 ps;
inv_1057: n_1325  <= TRANSPORT NOT dip(1) AFTER 1500 ps;
inv_1058: n_1326  <= TRANSPORT NOT pb1 AFTER 1500 ps;
delay_1059: n_1327  <= TRANSPORT dip(3) AFTER 1500 ps;
inv_1060: n_1328  <= TRANSPORT NOT n_1329;
and5_1061: n_1329 <= TRANSPORT  n_1330  AND n_1331  AND n_1332  AND n_1333
           AND n_1334 AFTER 5 ns;
inv_1062: n_1330  <= TRANSPORT NOT dip(4) AFTER 1500 ps;
inv_1063: n_1331  <= TRANSPORT NOT dip(3) AFTER 1500 ps;
inv_1064: n_1332  <= TRANSPORT NOT dip(1) AFTER 1500 ps;
inv_1065: n_1333  <= TRANSPORT NOT pb1 AFTER 1500 ps;
delay_1066: n_1334  <= TRANSPORT dip(2) AFTER 1500 ps;
inv_1067: n_1335  <= TRANSPORT NOT n_1336;
and5_1068: n_1336 <= TRANSPORT  n_1337  AND n_1338  AND n_1339  AND n_1340
           AND n_1341 AFTER 5 ns;
inv_1069: n_1337  <= TRANSPORT NOT dip(4) AFTER 1500 ps;
inv_1070: n_1338  <= TRANSPORT NOT dip(3) AFTER 1500 ps;
inv_1071: n_1339  <= TRANSPORT NOT dip(2) AFTER 1500 ps;
inv_1072: n_1340  <= TRANSPORT NOT pb1 AFTER 1500 ps;
delay_1073: n_1341  <= TRANSPORT dip(1) AFTER 1500 ps;
inv_1074: n_1342  <= TRANSPORT NOT n_1343;
and5_1075: n_1343 <= TRANSPORT  n_1344  AND n_1345  AND n_1346  AND n_1347
           AND n_1348 AFTER 5 ns;
inv_1076: n_1344  <= TRANSPORT NOT dip(4) AFTER 1500 ps;
inv_1077: n_1345  <= TRANSPORT NOT dip(3) AFTER 1500 ps;
inv_1078: n_1346  <= TRANSPORT NOT dip(2) AFTER 1500 ps;
inv_1079: n_1347  <= TRANSPORT NOT dip(1) AFTER 1500 ps;
delay_1080: n_1348  <= TRANSPORT pb1 AFTER 1500 ps;
inv_1081: n_1349  <= TRANSPORT NOT n_1350;
and5_1082: n_1350 <= TRANSPORT  n_1351  AND n_1352  AND n_1353  AND n_1354
           AND n_1355 AFTER 5 ns;
inv_1083: n_1351  <= TRANSPORT NOT dip(1) AFTER 1500 ps;
inv_1084: n_1352  <= TRANSPORT NOT pb1 AFTER 1500 ps;
delay_1085: n_1353  <= TRANSPORT dip(2) AFTER 1500 ps;
delay_1086: n_1354  <= TRANSPORT dip(3) AFTER 1500 ps;
delay_1087: n_1355  <= TRANSPORT dip(4) AFTER 1500 ps;
inv_1088: n_1356  <= TRANSPORT NOT n_1357;
and5_1089: n_1357 <= TRANSPORT  n_1358  AND n_1359  AND n_1360  AND n_1361
           AND n_1362 AFTER 5 ns;
inv_1090: n_1358  <= TRANSPORT NOT dip(2) AFTER 1500 ps;
inv_1091: n_1359  <= TRANSPORT NOT pb1 AFTER 1500 ps;
delay_1092: n_1360  <= TRANSPORT dip(1) AFTER 1500 ps;
delay_1093: n_1361  <= TRANSPORT dip(3) AFTER 1500 ps;
delay_1094: n_1362  <= TRANSPORT dip(4) AFTER 1500 ps;
inv_1095: n_1363  <= TRANSPORT NOT n_1364;
and5_1096: n_1364 <= TRANSPORT  n_1365  AND n_1366  AND n_1367  AND n_1368
           AND n_1369 AFTER 5 ns;
inv_1097: n_1365  <= TRANSPORT NOT dip(2) AFTER 1500 ps;
inv_1098: n_1366  <= TRANSPORT NOT dip(1) AFTER 1500 ps;
delay_1099: n_1367  <= TRANSPORT pb1 AFTER 1500 ps;
delay_1100: n_1368  <= TRANSPORT dip(3) AFTER 1500 ps;
delay_1101: n_1369  <= TRANSPORT dip(4) AFTER 1500 ps;
inv_1102: n_1370  <= TRANSPORT NOT n_1371;
and5_1103: n_1371 <= TRANSPORT  n_1372  AND n_1373  AND n_1374  AND n_1375
           AND n_1376 AFTER 5 ns;
inv_1104: n_1372  <= TRANSPORT NOT dip(3) AFTER 1500 ps;
inv_1105: n_1373  <= TRANSPORT NOT pb1 AFTER 1500 ps;
delay_1106: n_1374  <= TRANSPORT dip(1) AFTER 1500 ps;
delay_1107: n_1375  <= TRANSPORT dip(2) AFTER 1500 ps;
delay_1108: n_1376  <= TRANSPORT dip(4) AFTER 1500 ps;
inv_1109: n_1377  <= TRANSPORT NOT n_1378;
and5_1110: n_1378 <= TRANSPORT  n_1379  AND n_1380  AND n_1381  AND n_1382
           AND n_1383 AFTER 5 ns;
inv_1111: n_1379  <= TRANSPORT NOT dip(3) AFTER 1500 ps;
inv_1112: n_1380  <= TRANSPORT NOT dip(1) AFTER 1500 ps;
delay_1113: n_1381  <= TRANSPORT pb1 AFTER 1500 ps;
delay_1114: n_1382  <= TRANSPORT dip(2) AFTER 1500 ps;
delay_1115: n_1383  <= TRANSPORT dip(4) AFTER 1500 ps;
inv_1116: n_1384  <= TRANSPORT NOT n_1385;
and5_1117: n_1385 <= TRANSPORT  n_1386  AND n_1387  AND n_1388  AND n_1389
           AND n_1390 AFTER 5 ns;
inv_1118: n_1386  <= TRANSPORT NOT dip(3) AFTER 1500 ps;
inv_1119: n_1387  <= TRANSPORT NOT dip(2) AFTER 1500 ps;
delay_1120: n_1388  <= TRANSPORT pb1 AFTER 1500 ps;
delay_1121: n_1389  <= TRANSPORT dip(1) AFTER 1500 ps;
delay_1122: n_1390  <= TRANSPORT dip(4) AFTER 1500 ps;
inv_1123: n_1391  <= TRANSPORT NOT n_1392;
and5_1124: n_1392 <= TRANSPORT  n_1393  AND n_1394  AND n_1395  AND n_1396
           AND n_1397 AFTER 5 ns;
inv_1125: n_1393  <= TRANSPORT NOT dip(4) AFTER 1500 ps;
inv_1126: n_1394  <= TRANSPORT NOT pb1 AFTER 1500 ps;
delay_1127: n_1395  <= TRANSPORT dip(1) AFTER 1500 ps;
delay_1128: n_1396  <= TRANSPORT dip(2) AFTER 1500 ps;
delay_1129: n_1397  <= TRANSPORT dip(3) AFTER 1500 ps;
inv_1130: n_1398  <= TRANSPORT NOT n_1399;
and5_1131: n_1399 <= TRANSPORT  n_1400  AND n_1401  AND n_1402  AND n_1403
           AND n_1404 AFTER 5 ns;
inv_1132: n_1400  <= TRANSPORT NOT dip(4) AFTER 1500 ps;
inv_1133: n_1401  <= TRANSPORT NOT dip(1) AFTER 1500 ps;
delay_1134: n_1402  <= TRANSPORT pb1 AFTER 1500 ps;
delay_1135: n_1403  <= TRANSPORT dip(2) AFTER 1500 ps;
delay_1136: n_1404  <= TRANSPORT dip(3) AFTER 1500 ps;
inv_1137: n_1405  <= TRANSPORT NOT n_1406;
and5_1138: n_1406 <= TRANSPORT  n_1407  AND n_1408  AND n_1409  AND n_1410
           AND n_1411 AFTER 5 ns;
inv_1139: n_1407  <= TRANSPORT NOT dip(4) AFTER 1500 ps;
inv_1140: n_1408  <= TRANSPORT NOT dip(2) AFTER 1500 ps;
delay_1141: n_1409  <= TRANSPORT pb1 AFTER 1500 ps;
delay_1142: n_1410  <= TRANSPORT dip(1) AFTER 1500 ps;
delay_1143: n_1411  <= TRANSPORT dip(3) AFTER 1500 ps;
inv_1144: n_1412  <= TRANSPORT NOT n_1413;
and5_1145: n_1413 <= TRANSPORT  n_1414  AND n_1415  AND n_1416  AND n_1417
           AND n_1418 AFTER 5 ns;
inv_1146: n_1414  <= TRANSPORT NOT dip(4) AFTER 1500 ps;
inv_1147: n_1415  <= TRANSPORT NOT dip(3) AFTER 1500 ps;
delay_1148: n_1416  <= TRANSPORT pb1 AFTER 1500 ps;
delay_1149: n_1417  <= TRANSPORT dip(1) AFTER 1500 ps;
delay_1150: n_1418  <= TRANSPORT dip(2) AFTER 1500 ps;
inv_1151: n_1419  <= TRANSPORT NOT n_1420;
and5_1152: n_1420 <= TRANSPORT  n_1421  AND n_1422  AND n_1423  AND n_1424
           AND n_1425 AFTER 5 ns;
delay_1153: n_1421  <= TRANSPORT pb1 AFTER 1500 ps;
delay_1154: n_1422  <= TRANSPORT dip(1) AFTER 1500 ps;
delay_1155: n_1423  <= TRANSPORT dip(2) AFTER 1500 ps;
delay_1156: n_1424  <= TRANSPORT dip(3) AFTER 1500 ps;
delay_1157: n_1425  <= TRANSPORT dip(4) AFTER 1500 ps;
and1_1158: n_1426 <= TRANSPORT  n_1427 AFTER 5 ns;
inv_1159: n_1427  <= TRANSPORT NOT input84 AFTER 1500 ps;
dff_1160: DFF_test5
    GENERIC MAP (data_pin => " \slow_crystal.D\", treg => 2 ns, trsu => 2 ns, trh => 3 ns, trpr => 3 ns, trcl => 3 ns)
    PORT MAP ( D => \slow_crystal.D\, CLK => \slow_crystal.CLK\, CLRN => \slow_crystal.CLRN\,
          PRN => \slow_crystal.PRN\, Q => slow_crystal_Q);
inv_1161: \slow_crystal.PRN\  <= TRANSPORT NOT gnd;
inv_1162: \slow_crystal.CLRN\  <= TRANSPORT NOT gnd;
xor2_1163: \slow_crystal.D\ <=  \:2586\  XOR n_1438;
or1_1164: \:2586\ <=  n_1436;
and1_1165: n_1436 <= TRANSPORT  n_1437 AFTER 5 ns;
delay_1166: n_1437  <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\ AFTER 1 ns;
and1_1167: n_1438 <= TRANSPORT  n_1439 AFTER 5 ns;
delay_1168: n_1439  <= TRANSPORT slow_crystal_Q AFTER 1 ns;
delay_1169: n_1440  <= TRANSPORT n_1286;
filter_1170: FILTER_test5
    GENERIC MAP (inst_name => "filter_1170", tlow => 4 ns, thigh => 4 ns)
    PORT MAP (IN1 => n_1440, Y => \slow_crystal.CLK\);
delay_1171: \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.OUT\
           <= TRANSPORT \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.IN\ AFTER 2 ns;
xor2_1172: \|lpm_compare:2243|comptree:comparator|cmpchain:cmp_end|aeb_out.IN\ <=
           n_1443  XOR n_1304;
or1_1173: n_1443 <=  n_1446;
and2_1174: n_1446 <= TRANSPORT  n_1444  AND n_1445 AFTER 5 ns;
and16_1175: n_1444 <=  n_1447  AND n_1448  AND n_1449  AND n_1450  AND n_1451
           AND n_1452  AND n_1453  AND n_1454  AND n_1455  AND n_1456  AND n_1457
           AND n_1458  AND n_1459  AND n_1460  AND n_1461  AND n_1462;
and8_1176: n_1445 <=  n_1463  AND n_1464  AND n_1465  AND n_1466  AND n_1467
           AND n_1468  AND n_1469  AND n_1470;
inv_1177: n_1447  <= TRANSPORT NOT clock_count0_Q AFTER 1 ns;
inv_1178: n_1448  <= TRANSPORT NOT clock_count1_Q AFTER 1 ns;
inv_1179: n_1449  <= TRANSPORT NOT clock_count2_Q AFTER 1 ns;
inv_1180: n_1450  <= TRANSPORT NOT clock_count3_Q AFTER 1 ns;
inv_1181: n_1451  <= TRANSPORT NOT clock_count4_Q AFTER 1 ns;
inv_1182: n_1452  <= TRANSPORT NOT clock_count5_Q AFTER 1 ns;
inv_1183: n_1453  <= TRANSPORT NOT clock_count6_Q AFTER 1 ns;
inv_1184: n_1454  <= TRANSPORT NOT clock_count8_Q AFTER 1 ns;
inv_1185: n_1455  <= TRANSPORT NOT clock_count9_Q AFTER 1 ns;
inv_1186: n_1456  <= TRANSPORT NOT clock_count11_Q AFTER 1 ns;
inv_1187: n_1457  <= TRANSPORT NOT clock_count12_Q AFTER 1 ns;
inv_1188: n_1458  <= TRANSPORT NOT clock_count13_Q AFTER 1 ns;
inv_1189: n_1459  <= TRANSPORT NOT clock_count14_Q AFTER 1 ns;
inv_1190: n_1460  <= TRANSPORT NOT clock_count16_Q AFTER 1 ns;
inv_1191: n_1461  <= TRANSPORT NOT clock_count21_Q AFTER 1 ns;
inv_1192: n_1462  <= TRANSPORT NOT clock_count22_Q AFTER 1 ns;
inv_1193: n_1463  <= TRANSPORT NOT clock_count23_Q AFTER 1 ns;
delay_1194: n_1464  <= TRANSPORT clock_count20_Q AFTER 1 ns;
delay_1195: n_1465  <= TRANSPORT clock_count19_Q AFTER 1 ns;
delay_1196: n_1466  <= TRANSPORT clock_count18_Q AFTER 1 ns;
delay_1197: n_1467  <= TRANSPORT clock_count17_Q AFTER 1 ns;
delay_1198: n_1468  <= TRANSPORT clock_count15_Q AFTER 1 ns;
delay_1199: n_1469  <= TRANSPORT clock_count10_Q AFTER 1 ns;
delay_1200: n_1470  <= TRANSPORT clock_count7_Q AFTER 1 ns;

END \EPM7128SLC84-10\;
